# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.color_config import ColorConfig
from bitmovin_api_sdk.models.display_aspect_ratio import DisplayAspectRatio
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.pixel_format import PixelFormat
from bitmovin_api_sdk.models.preset_configuration import PresetConfiguration
from bitmovin_api_sdk.models.video_configuration import VideoConfiguration
from bitmovin_api_sdk.models.vp9_aq_mode import Vp9AqMode
from bitmovin_api_sdk.models.vp9_arnr_type import Vp9ArnrType
from bitmovin_api_sdk.models.vp9_dynamic_range_format import Vp9DynamicRangeFormat
from bitmovin_api_sdk.models.vp9_quality import Vp9Quality
import pprint
import six


class Vp9VideoConfiguration(VideoConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 width=None,
                 height=None,
                 bitrate=None,
                 rate=None,
                 pixel_format=None,
                 color_config=None,
                 sample_aspect_ratio_numerator=None,
                 sample_aspect_ratio_denominator=None,
                 display_aspect_ratio=None,
                 encoding_mode=None,
                 preset_configuration=None,
                 dynamic_range_format=None,
                 crf=None,
                 lag_in_frames=None,
                 error_resiliency_enabled=None,
                 tile_columns=None,
                 tile_rows=None,
                 frame_parallel=None,
                 max_intra_rate=None,
                 qp_min=None,
                 qp_max=None,
                 rate_undershoot_pct=None,
                 rate_overshoot_pct=None,
                 client_buffer_size=None,
                 client_initial_buffer_size=None,
                 bias_pct=None,
                 noise_sensitivity=None,
                 cpu_used=None,
                 automatic_alt_ref_frames_enabled=None,
                 target_level=None,
                 row_multi_threading_enabled=None,
                 sharpness=None,
                 min_gop=None,
                 max_gop=None,
                 min_keyframe_interval=None,
                 max_keyframe_interval=None,
                 quality=None,
                 lossless=None,
                 static_thresh=None,
                 aq_mode=None,
                 arnr_max_frames=None,
                 arnr_strength=None,
                 arnr_type=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, int, float, PixelFormat, ColorConfig, int, int, DisplayAspectRatio, EncodingMode, PresetConfiguration, Vp9DynamicRangeFormat, int, int, bool, int, int, bool, int, int, int, int, int, int, int, int, bool, int, bool, int, bool, int, int, int, float, float, Vp9Quality, bool, int, Vp9AqMode, int, int, Vp9ArnrType) -> None
        super(Vp9VideoConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, width=width, height=height, bitrate=bitrate, rate=rate, pixel_format=pixel_format, color_config=color_config, sample_aspect_ratio_numerator=sample_aspect_ratio_numerator, sample_aspect_ratio_denominator=sample_aspect_ratio_denominator, display_aspect_ratio=display_aspect_ratio, encoding_mode=encoding_mode)

        self._preset_configuration = None
        self._dynamic_range_format = None
        self._crf = None
        self._lag_in_frames = None
        self._error_resiliency_enabled = None
        self._tile_columns = None
        self._tile_rows = None
        self._frame_parallel = None
        self._max_intra_rate = None
        self._qp_min = None
        self._qp_max = None
        self._rate_undershoot_pct = None
        self._rate_overshoot_pct = None
        self._client_buffer_size = None
        self._client_initial_buffer_size = None
        self._bias_pct = None
        self._noise_sensitivity = None
        self._cpu_used = None
        self._automatic_alt_ref_frames_enabled = None
        self._target_level = None
        self._row_multi_threading_enabled = None
        self._sharpness = None
        self._min_gop = None
        self._max_gop = None
        self._min_keyframe_interval = None
        self._max_keyframe_interval = None
        self._quality = None
        self._lossless = None
        self._static_thresh = None
        self._aq_mode = None
        self._arnr_max_frames = None
        self._arnr_strength = None
        self._arnr_type = None
        self.discriminator = None

        if preset_configuration is not None:
            self.preset_configuration = preset_configuration
        if dynamic_range_format is not None:
            self.dynamic_range_format = dynamic_range_format
        if crf is not None:
            self.crf = crf
        if lag_in_frames is not None:
            self.lag_in_frames = lag_in_frames
        if error_resiliency_enabled is not None:
            self.error_resiliency_enabled = error_resiliency_enabled
        if tile_columns is not None:
            self.tile_columns = tile_columns
        if tile_rows is not None:
            self.tile_rows = tile_rows
        if frame_parallel is not None:
            self.frame_parallel = frame_parallel
        if max_intra_rate is not None:
            self.max_intra_rate = max_intra_rate
        if qp_min is not None:
            self.qp_min = qp_min
        if qp_max is not None:
            self.qp_max = qp_max
        if rate_undershoot_pct is not None:
            self.rate_undershoot_pct = rate_undershoot_pct
        if rate_overshoot_pct is not None:
            self.rate_overshoot_pct = rate_overshoot_pct
        if client_buffer_size is not None:
            self.client_buffer_size = client_buffer_size
        if client_initial_buffer_size is not None:
            self.client_initial_buffer_size = client_initial_buffer_size
        if bias_pct is not None:
            self.bias_pct = bias_pct
        if noise_sensitivity is not None:
            self.noise_sensitivity = noise_sensitivity
        if cpu_used is not None:
            self.cpu_used = cpu_used
        if automatic_alt_ref_frames_enabled is not None:
            self.automatic_alt_ref_frames_enabled = automatic_alt_ref_frames_enabled
        if target_level is not None:
            self.target_level = target_level
        if row_multi_threading_enabled is not None:
            self.row_multi_threading_enabled = row_multi_threading_enabled
        if sharpness is not None:
            self.sharpness = sharpness
        if min_gop is not None:
            self.min_gop = min_gop
        if max_gop is not None:
            self.max_gop = max_gop
        if min_keyframe_interval is not None:
            self.min_keyframe_interval = min_keyframe_interval
        if max_keyframe_interval is not None:
            self.max_keyframe_interval = max_keyframe_interval
        if quality is not None:
            self.quality = quality
        if lossless is not None:
            self.lossless = lossless
        if static_thresh is not None:
            self.static_thresh = static_thresh
        if aq_mode is not None:
            self.aq_mode = aq_mode
        if arnr_max_frames is not None:
            self.arnr_max_frames = arnr_max_frames
        if arnr_strength is not None:
            self.arnr_strength = arnr_strength
        if arnr_type is not None:
            self.arnr_type = arnr_type

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Vp9VideoConfiguration, self), 'openapi_types'):
            types = getattr(super(Vp9VideoConfiguration, self), 'openapi_types')

        types.update({
            'preset_configuration': 'PresetConfiguration',
            'dynamic_range_format': 'Vp9DynamicRangeFormat',
            'crf': 'int',
            'lag_in_frames': 'int',
            'error_resiliency_enabled': 'bool',
            'tile_columns': 'int',
            'tile_rows': 'int',
            'frame_parallel': 'bool',
            'max_intra_rate': 'int',
            'qp_min': 'int',
            'qp_max': 'int',
            'rate_undershoot_pct': 'int',
            'rate_overshoot_pct': 'int',
            'client_buffer_size': 'int',
            'client_initial_buffer_size': 'int',
            'bias_pct': 'int',
            'noise_sensitivity': 'bool',
            'cpu_used': 'int',
            'automatic_alt_ref_frames_enabled': 'bool',
            'target_level': 'int',
            'row_multi_threading_enabled': 'bool',
            'sharpness': 'int',
            'min_gop': 'int',
            'max_gop': 'int',
            'min_keyframe_interval': 'float',
            'max_keyframe_interval': 'float',
            'quality': 'Vp9Quality',
            'lossless': 'bool',
            'static_thresh': 'int',
            'aq_mode': 'Vp9AqMode',
            'arnr_max_frames': 'int',
            'arnr_strength': 'int',
            'arnr_type': 'Vp9ArnrType'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Vp9VideoConfiguration, self), 'attribute_map'):
            attributes = getattr(super(Vp9VideoConfiguration, self), 'attribute_map')

        attributes.update({
            'preset_configuration': 'presetConfiguration',
            'dynamic_range_format': 'dynamicRangeFormat',
            'crf': 'crf',
            'lag_in_frames': 'lagInFrames',
            'error_resiliency_enabled': 'errorResiliencyEnabled',
            'tile_columns': 'tileColumns',
            'tile_rows': 'tileRows',
            'frame_parallel': 'frameParallel',
            'max_intra_rate': 'maxIntraRate',
            'qp_min': 'qpMin',
            'qp_max': 'qpMax',
            'rate_undershoot_pct': 'rateUndershootPct',
            'rate_overshoot_pct': 'rateOvershootPct',
            'client_buffer_size': 'clientBufferSize',
            'client_initial_buffer_size': 'clientInitialBufferSize',
            'bias_pct': 'biasPct',
            'noise_sensitivity': 'noiseSensitivity',
            'cpu_used': 'cpuUsed',
            'automatic_alt_ref_frames_enabled': 'automaticAltRefFramesEnabled',
            'target_level': 'targetLevel',
            'row_multi_threading_enabled': 'rowMultiThreadingEnabled',
            'sharpness': 'sharpness',
            'min_gop': 'minGop',
            'max_gop': 'maxGop',
            'min_keyframe_interval': 'minKeyframeInterval',
            'max_keyframe_interval': 'maxKeyframeInterval',
            'quality': 'quality',
            'lossless': 'lossless',
            'static_thresh': 'staticThresh',
            'aq_mode': 'aqMode',
            'arnr_max_frames': 'arnrMaxFrames',
            'arnr_strength': 'arnrStrength',
            'arnr_type': 'arnrType'
        })
        return attributes

    @property
    def preset_configuration(self):
        # type: () -> PresetConfiguration
        """Gets the preset_configuration of this Vp9VideoConfiguration.

        Choose from a set of preset configurations tailored for common use cases. Check out [VP9 Presets](https://bitmovin.com/docs/encoding/tutorials/vp9-presets) to see which values get applied by each preset. Explicitly setting a property to a different value will override the preset's value for that property.

        :return: The preset_configuration of this Vp9VideoConfiguration.
        :rtype: PresetConfiguration
        """
        return self._preset_configuration

    @preset_configuration.setter
    def preset_configuration(self, preset_configuration):
        # type: (PresetConfiguration) -> None
        """Sets the preset_configuration of this Vp9VideoConfiguration.

        Choose from a set of preset configurations tailored for common use cases. Check out [VP9 Presets](https://bitmovin.com/docs/encoding/tutorials/vp9-presets) to see which values get applied by each preset. Explicitly setting a property to a different value will override the preset's value for that property.

        :param preset_configuration: The preset_configuration of this Vp9VideoConfiguration.
        :type: PresetConfiguration
        """

        if preset_configuration is not None:
            if not isinstance(preset_configuration, PresetConfiguration):
                raise TypeError("Invalid type for `preset_configuration`, type has to be `PresetConfiguration`")

        self._preset_configuration = preset_configuration

    @property
    def dynamic_range_format(self):
        # type: () -> Vp9DynamicRangeFormat
        """Gets the dynamic_range_format of this Vp9VideoConfiguration.

        Automatically configures the VP9 Video Codec to be compatible with the given SDR/HLG format. Bitmovin recommends to use the dynamic range format together with a preset configuration to achieve good results. Explicitly configured properties will take precedence over dynamic range format settings, which in turn will take precedence over preset configurations.

        :return: The dynamic_range_format of this Vp9VideoConfiguration.
        :rtype: Vp9DynamicRangeFormat
        """
        return self._dynamic_range_format

    @dynamic_range_format.setter
    def dynamic_range_format(self, dynamic_range_format):
        # type: (Vp9DynamicRangeFormat) -> None
        """Sets the dynamic_range_format of this Vp9VideoConfiguration.

        Automatically configures the VP9 Video Codec to be compatible with the given SDR/HLG format. Bitmovin recommends to use the dynamic range format together with a preset configuration to achieve good results. Explicitly configured properties will take precedence over dynamic range format settings, which in turn will take precedence over preset configurations.

        :param dynamic_range_format: The dynamic_range_format of this Vp9VideoConfiguration.
        :type: Vp9DynamicRangeFormat
        """

        if dynamic_range_format is not None:
            if not isinstance(dynamic_range_format, Vp9DynamicRangeFormat):
                raise TypeError("Invalid type for `dynamic_range_format`, type has to be `Vp9DynamicRangeFormat`")

        self._dynamic_range_format = dynamic_range_format

    @property
    def crf(self):
        # type: () -> int
        """Gets the crf of this Vp9VideoConfiguration.

        Constant rate factor for quality-based variable bitrate. Either bitrate or crf is required.

        :return: The crf of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._crf

    @crf.setter
    def crf(self, crf):
        # type: (int) -> None
        """Sets the crf of this Vp9VideoConfiguration.

        Constant rate factor for quality-based variable bitrate. Either bitrate or crf is required.

        :param crf: The crf of this Vp9VideoConfiguration.
        :type: int
        """

        if crf is not None:
            if crf is not None and crf > 63:
                raise ValueError("Invalid value for `crf`, must be a value less than or equal to `63`")
            if crf is not None and crf < 0:
                raise ValueError("Invalid value for `crf`, must be a value greater than or equal to `0`")
            if not isinstance(crf, int):
                raise TypeError("Invalid type for `crf`, type has to be `int`")

        self._crf = crf

    @property
    def lag_in_frames(self):
        # type: () -> int
        """Gets the lag_in_frames of this Vp9VideoConfiguration.

        Number of frames to look ahead for alternate reference frame selection.

        :return: The lag_in_frames of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._lag_in_frames

    @lag_in_frames.setter
    def lag_in_frames(self, lag_in_frames):
        # type: (int) -> None
        """Sets the lag_in_frames of this Vp9VideoConfiguration.

        Number of frames to look ahead for alternate reference frame selection.

        :param lag_in_frames: The lag_in_frames of this Vp9VideoConfiguration.
        :type: int
        """

        if lag_in_frames is not None:
            if lag_in_frames is not None and lag_in_frames > 25:
                raise ValueError("Invalid value for `lag_in_frames`, must be a value less than or equal to `25`")
            if lag_in_frames is not None and lag_in_frames < 0:
                raise ValueError("Invalid value for `lag_in_frames`, must be a value greater than or equal to `0`")
            if not isinstance(lag_in_frames, int):
                raise TypeError("Invalid type for `lag_in_frames`, type has to be `int`")

        self._lag_in_frames = lag_in_frames

    @property
    def error_resiliency_enabled(self):
        # type: () -> bool
        """Gets the error_resiliency_enabled of this Vp9VideoConfiguration.

        Enables error resiliency feature

        :return: The error_resiliency_enabled of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._error_resiliency_enabled

    @error_resiliency_enabled.setter
    def error_resiliency_enabled(self, error_resiliency_enabled):
        # type: (bool) -> None
        """Sets the error_resiliency_enabled of this Vp9VideoConfiguration.

        Enables error resiliency feature

        :param error_resiliency_enabled: The error_resiliency_enabled of this Vp9VideoConfiguration.
        :type: bool
        """

        if error_resiliency_enabled is not None:
            if not isinstance(error_resiliency_enabled, bool):
                raise TypeError("Invalid type for `error_resiliency_enabled`, type has to be `bool`")

        self._error_resiliency_enabled = error_resiliency_enabled

    @property
    def tile_columns(self):
        # type: () -> int
        """Gets the tile_columns of this Vp9VideoConfiguration.

        Number of tile columns to use, log2. Depending on the encoding width there are limitations on this value. The minimum values are 2 for width >= 1920 and 1 for width >= 1280. The minimum width of each tile is 256 pixels so the maximum values are 0 for width < 256, 1 for width < 512, 2 for width < 1024, 3 for width < 2048, 4 for width < 4096, 5 for width < 8192. If the value is too high or too low it will be overridden.

        :return: The tile_columns of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._tile_columns

    @tile_columns.setter
    def tile_columns(self, tile_columns):
        # type: (int) -> None
        """Sets the tile_columns of this Vp9VideoConfiguration.

        Number of tile columns to use, log2. Depending on the encoding width there are limitations on this value. The minimum values are 2 for width >= 1920 and 1 for width >= 1280. The minimum width of each tile is 256 pixels so the maximum values are 0 for width < 256, 1 for width < 512, 2 for width < 1024, 3 for width < 2048, 4 for width < 4096, 5 for width < 8192. If the value is too high or too low it will be overridden.

        :param tile_columns: The tile_columns of this Vp9VideoConfiguration.
        :type: int
        """

        if tile_columns is not None:
            if tile_columns is not None and tile_columns > 6:
                raise ValueError("Invalid value for `tile_columns`, must be a value less than or equal to `6`")
            if tile_columns is not None and tile_columns < 0:
                raise ValueError("Invalid value for `tile_columns`, must be a value greater than or equal to `0`")
            if not isinstance(tile_columns, int):
                raise TypeError("Invalid type for `tile_columns`, type has to be `int`")

        self._tile_columns = tile_columns

    @property
    def tile_rows(self):
        # type: () -> int
        """Gets the tile_rows of this Vp9VideoConfiguration.

        Number of tile rows to use, log2.

        :return: The tile_rows of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._tile_rows

    @tile_rows.setter
    def tile_rows(self, tile_rows):
        # type: (int) -> None
        """Sets the tile_rows of this Vp9VideoConfiguration.

        Number of tile rows to use, log2.

        :param tile_rows: The tile_rows of this Vp9VideoConfiguration.
        :type: int
        """

        if tile_rows is not None:
            if tile_rows is not None and tile_rows > 2:
                raise ValueError("Invalid value for `tile_rows`, must be a value less than or equal to `2`")
            if tile_rows is not None and tile_rows < 0:
                raise ValueError("Invalid value for `tile_rows`, must be a value greater than or equal to `0`")
            if not isinstance(tile_rows, int):
                raise TypeError("Invalid type for `tile_rows`, type has to be `int`")

        self._tile_rows = tile_rows

    @property
    def frame_parallel(self):
        # type: () -> bool
        """Gets the frame_parallel of this Vp9VideoConfiguration.

        Enable frame parallel decodability features

        :return: The frame_parallel of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._frame_parallel

    @frame_parallel.setter
    def frame_parallel(self, frame_parallel):
        # type: (bool) -> None
        """Sets the frame_parallel of this Vp9VideoConfiguration.

        Enable frame parallel decodability features

        :param frame_parallel: The frame_parallel of this Vp9VideoConfiguration.
        :type: bool
        """

        if frame_parallel is not None:
            if not isinstance(frame_parallel, bool):
                raise TypeError("Invalid type for `frame_parallel`, type has to be `bool`")

        self._frame_parallel = frame_parallel

    @property
    def max_intra_rate(self):
        # type: () -> int
        """Gets the max_intra_rate of this Vp9VideoConfiguration.

        Maximum I-frame bitrate (percentage) 0=unlimited

        :return: The max_intra_rate of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._max_intra_rate

    @max_intra_rate.setter
    def max_intra_rate(self, max_intra_rate):
        # type: (int) -> None
        """Sets the max_intra_rate of this Vp9VideoConfiguration.

        Maximum I-frame bitrate (percentage) 0=unlimited

        :param max_intra_rate: The max_intra_rate of this Vp9VideoConfiguration.
        :type: int
        """

        if max_intra_rate is not None:
            if not isinstance(max_intra_rate, int):
                raise TypeError("Invalid type for `max_intra_rate`, type has to be `int`")

        self._max_intra_rate = max_intra_rate

    @property
    def qp_min(self):
        # type: () -> int
        """Gets the qp_min of this Vp9VideoConfiguration.

        Minimum quantization factor.

        :return: The qp_min of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._qp_min

    @qp_min.setter
    def qp_min(self, qp_min):
        # type: (int) -> None
        """Sets the qp_min of this Vp9VideoConfiguration.

        Minimum quantization factor.

        :param qp_min: The qp_min of this Vp9VideoConfiguration.
        :type: int
        """

        if qp_min is not None:
            if qp_min is not None and qp_min > 63:
                raise ValueError("Invalid value for `qp_min`, must be a value less than or equal to `63`")
            if qp_min is not None and qp_min < 0:
                raise ValueError("Invalid value for `qp_min`, must be a value greater than or equal to `0`")
            if not isinstance(qp_min, int):
                raise TypeError("Invalid type for `qp_min`, type has to be `int`")

        self._qp_min = qp_min

    @property
    def qp_max(self):
        # type: () -> int
        """Gets the qp_max of this Vp9VideoConfiguration.

        Maximum quantization factor.

        :return: The qp_max of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._qp_max

    @qp_max.setter
    def qp_max(self, qp_max):
        # type: (int) -> None
        """Sets the qp_max of this Vp9VideoConfiguration.

        Maximum quantization factor.

        :param qp_max: The qp_max of this Vp9VideoConfiguration.
        :type: int
        """

        if qp_max is not None:
            if qp_max is not None and qp_max > 63:
                raise ValueError("Invalid value for `qp_max`, must be a value less than or equal to `63`")
            if qp_max is not None and qp_max < 0:
                raise ValueError("Invalid value for `qp_max`, must be a value greater than or equal to `0`")
            if not isinstance(qp_max, int):
                raise TypeError("Invalid type for `qp_max`, type has to be `int`")

        self._qp_max = qp_max

    @property
    def rate_undershoot_pct(self):
        # type: () -> int
        """Gets the rate_undershoot_pct of this Vp9VideoConfiguration.

        Datarate undershoot (min) target (percentage).

        :return: The rate_undershoot_pct of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._rate_undershoot_pct

    @rate_undershoot_pct.setter
    def rate_undershoot_pct(self, rate_undershoot_pct):
        # type: (int) -> None
        """Sets the rate_undershoot_pct of this Vp9VideoConfiguration.

        Datarate undershoot (min) target (percentage).

        :param rate_undershoot_pct: The rate_undershoot_pct of this Vp9VideoConfiguration.
        :type: int
        """

        if rate_undershoot_pct is not None:
            if rate_undershoot_pct is not None and rate_undershoot_pct > 100:
                raise ValueError("Invalid value for `rate_undershoot_pct`, must be a value less than or equal to `100`")
            if rate_undershoot_pct is not None and rate_undershoot_pct < 0:
                raise ValueError("Invalid value for `rate_undershoot_pct`, must be a value greater than or equal to `0`")
            if not isinstance(rate_undershoot_pct, int):
                raise TypeError("Invalid type for `rate_undershoot_pct`, type has to be `int`")

        self._rate_undershoot_pct = rate_undershoot_pct

    @property
    def rate_overshoot_pct(self):
        # type: () -> int
        """Gets the rate_overshoot_pct of this Vp9VideoConfiguration.

        Datarate overshoot (max) target (percentage).

        :return: The rate_overshoot_pct of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._rate_overshoot_pct

    @rate_overshoot_pct.setter
    def rate_overshoot_pct(self, rate_overshoot_pct):
        # type: (int) -> None
        """Sets the rate_overshoot_pct of this Vp9VideoConfiguration.

        Datarate overshoot (max) target (percentage).

        :param rate_overshoot_pct: The rate_overshoot_pct of this Vp9VideoConfiguration.
        :type: int
        """

        if rate_overshoot_pct is not None:
            if rate_overshoot_pct is not None and rate_overshoot_pct > 100:
                raise ValueError("Invalid value for `rate_overshoot_pct`, must be a value less than or equal to `100`")
            if rate_overshoot_pct is not None and rate_overshoot_pct < 0:
                raise ValueError("Invalid value for `rate_overshoot_pct`, must be a value greater than or equal to `0`")
            if not isinstance(rate_overshoot_pct, int):
                raise TypeError("Invalid type for `rate_overshoot_pct`, type has to be `int`")

        self._rate_overshoot_pct = rate_overshoot_pct

    @property
    def client_buffer_size(self):
        # type: () -> int
        """Gets the client_buffer_size of this Vp9VideoConfiguration.

        Client buffer size (ms)

        :return: The client_buffer_size of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._client_buffer_size

    @client_buffer_size.setter
    def client_buffer_size(self, client_buffer_size):
        # type: (int) -> None
        """Sets the client_buffer_size of this Vp9VideoConfiguration.

        Client buffer size (ms)

        :param client_buffer_size: The client_buffer_size of this Vp9VideoConfiguration.
        :type: int
        """

        if client_buffer_size is not None:
            if client_buffer_size is not None and client_buffer_size < 0:
                raise ValueError("Invalid value for `client_buffer_size`, must be a value greater than or equal to `0`")
            if not isinstance(client_buffer_size, int):
                raise TypeError("Invalid type for `client_buffer_size`, type has to be `int`")

        self._client_buffer_size = client_buffer_size

    @property
    def client_initial_buffer_size(self):
        # type: () -> int
        """Gets the client_initial_buffer_size of this Vp9VideoConfiguration.

        Client initial buffer size (ms)

        :return: The client_initial_buffer_size of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._client_initial_buffer_size

    @client_initial_buffer_size.setter
    def client_initial_buffer_size(self, client_initial_buffer_size):
        # type: (int) -> None
        """Sets the client_initial_buffer_size of this Vp9VideoConfiguration.

        Client initial buffer size (ms)

        :param client_initial_buffer_size: The client_initial_buffer_size of this Vp9VideoConfiguration.
        :type: int
        """

        if client_initial_buffer_size is not None:
            if client_initial_buffer_size is not None and client_initial_buffer_size < 0:
                raise ValueError("Invalid value for `client_initial_buffer_size`, must be a value greater than or equal to `0`")
            if not isinstance(client_initial_buffer_size, int):
                raise TypeError("Invalid type for `client_initial_buffer_size`, type has to be `int`")

        self._client_initial_buffer_size = client_initial_buffer_size

    @property
    def bias_pct(self):
        # type: () -> int
        """Gets the bias_pct of this Vp9VideoConfiguration.

        CBR/VBR bias (0=CBR, 100=VBR)

        :return: The bias_pct of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._bias_pct

    @bias_pct.setter
    def bias_pct(self, bias_pct):
        # type: (int) -> None
        """Sets the bias_pct of this Vp9VideoConfiguration.

        CBR/VBR bias (0=CBR, 100=VBR)

        :param bias_pct: The bias_pct of this Vp9VideoConfiguration.
        :type: int
        """

        if bias_pct is not None:
            if bias_pct is not None and bias_pct > 100:
                raise ValueError("Invalid value for `bias_pct`, must be a value less than or equal to `100`")
            if bias_pct is not None and bias_pct < 0:
                raise ValueError("Invalid value for `bias_pct`, must be a value greater than or equal to `0`")
            if not isinstance(bias_pct, int):
                raise TypeError("Invalid type for `bias_pct`, type has to be `int`")

        self._bias_pct = bias_pct

    @property
    def noise_sensitivity(self):
        # type: () -> bool
        """Gets the noise_sensitivity of this Vp9VideoConfiguration.

        Enable noise sensitivity on Y channel

        :return: The noise_sensitivity of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._noise_sensitivity

    @noise_sensitivity.setter
    def noise_sensitivity(self, noise_sensitivity):
        # type: (bool) -> None
        """Sets the noise_sensitivity of this Vp9VideoConfiguration.

        Enable noise sensitivity on Y channel

        :param noise_sensitivity: The noise_sensitivity of this Vp9VideoConfiguration.
        :type: bool
        """

        if noise_sensitivity is not None:
            if not isinstance(noise_sensitivity, bool):
                raise TypeError("Invalid type for `noise_sensitivity`, type has to be `bool`")

        self._noise_sensitivity = noise_sensitivity

    @property
    def cpu_used(self):
        # type: () -> int
        """Gets the cpu_used of this Vp9VideoConfiguration.

        Controls the tradeoff between compression efficiency and encoding speed. Higher values indicate a faster encoding. The minimum value for width * height >= 1280 * 720 is 2. If the value is too low it will be overridden.

        :return: The cpu_used of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._cpu_used

    @cpu_used.setter
    def cpu_used(self, cpu_used):
        # type: (int) -> None
        """Sets the cpu_used of this Vp9VideoConfiguration.

        Controls the tradeoff between compression efficiency and encoding speed. Higher values indicate a faster encoding. The minimum value for width * height >= 1280 * 720 is 2. If the value is too low it will be overridden.

        :param cpu_used: The cpu_used of this Vp9VideoConfiguration.
        :type: int
        """

        if cpu_used is not None:
            if cpu_used is not None and cpu_used > 8:
                raise ValueError("Invalid value for `cpu_used`, must be a value less than or equal to `8`")
            if cpu_used is not None and cpu_used < 1:
                raise ValueError("Invalid value for `cpu_used`, must be a value greater than or equal to `1`")
            if not isinstance(cpu_used, int):
                raise TypeError("Invalid type for `cpu_used`, type has to be `int`")

        self._cpu_used = cpu_used

    @property
    def automatic_alt_ref_frames_enabled(self):
        # type: () -> bool
        """Gets the automatic_alt_ref_frames_enabled of this Vp9VideoConfiguration.

        Enable automatic alternate reference frames (2pass only)

        :return: The automatic_alt_ref_frames_enabled of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._automatic_alt_ref_frames_enabled

    @automatic_alt_ref_frames_enabled.setter
    def automatic_alt_ref_frames_enabled(self, automatic_alt_ref_frames_enabled):
        # type: (bool) -> None
        """Sets the automatic_alt_ref_frames_enabled of this Vp9VideoConfiguration.

        Enable automatic alternate reference frames (2pass only)

        :param automatic_alt_ref_frames_enabled: The automatic_alt_ref_frames_enabled of this Vp9VideoConfiguration.
        :type: bool
        """

        if automatic_alt_ref_frames_enabled is not None:
            if not isinstance(automatic_alt_ref_frames_enabled, bool):
                raise TypeError("Invalid type for `automatic_alt_ref_frames_enabled`, type has to be `bool`")

        self._automatic_alt_ref_frames_enabled = automatic_alt_ref_frames_enabled

    @property
    def target_level(self):
        # type: () -> int
        """Gets the target_level of this Vp9VideoConfiguration.

        Target level (255: off, 0: only keep level stats; 10: level 1.0; 11: level 1.1; ... 62: level 6.2)

        :return: The target_level of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._target_level

    @target_level.setter
    def target_level(self, target_level):
        # type: (int) -> None
        """Sets the target_level of this Vp9VideoConfiguration.

        Target level (255: off, 0: only keep level stats; 10: level 1.0; 11: level 1.1; ... 62: level 6.2)

        :param target_level: The target_level of this Vp9VideoConfiguration.
        :type: int
        """

        if target_level is not None:
            if target_level is not None and target_level > 255:
                raise ValueError("Invalid value for `target_level`, must be a value less than or equal to `255`")
            if target_level is not None and target_level < 0:
                raise ValueError("Invalid value for `target_level`, must be a value greater than or equal to `0`")
            if not isinstance(target_level, int):
                raise TypeError("Invalid type for `target_level`, type has to be `int`")

        self._target_level = target_level

    @property
    def row_multi_threading_enabled(self):
        # type: () -> bool
        """Gets the row_multi_threading_enabled of this Vp9VideoConfiguration.

        Enable row based non-deterministic multi-threading

        :return: The row_multi_threading_enabled of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._row_multi_threading_enabled

    @row_multi_threading_enabled.setter
    def row_multi_threading_enabled(self, row_multi_threading_enabled):
        # type: (bool) -> None
        """Sets the row_multi_threading_enabled of this Vp9VideoConfiguration.

        Enable row based non-deterministic multi-threading

        :param row_multi_threading_enabled: The row_multi_threading_enabled of this Vp9VideoConfiguration.
        :type: bool
        """

        if row_multi_threading_enabled is not None:
            if not isinstance(row_multi_threading_enabled, bool):
                raise TypeError("Invalid type for `row_multi_threading_enabled`, type has to be `bool`")

        self._row_multi_threading_enabled = row_multi_threading_enabled

    @property
    def sharpness(self):
        # type: () -> int
        """Gets the sharpness of this Vp9VideoConfiguration.

        Loop filter sharpness.

        :return: The sharpness of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._sharpness

    @sharpness.setter
    def sharpness(self, sharpness):
        # type: (int) -> None
        """Sets the sharpness of this Vp9VideoConfiguration.

        Loop filter sharpness.

        :param sharpness: The sharpness of this Vp9VideoConfiguration.
        :type: int
        """

        if sharpness is not None:
            if sharpness is not None and sharpness > 7:
                raise ValueError("Invalid value for `sharpness`, must be a value less than or equal to `7`")
            if sharpness is not None and sharpness < 0:
                raise ValueError("Invalid value for `sharpness`, must be a value greater than or equal to `0`")
            if not isinstance(sharpness, int):
                raise TypeError("Invalid type for `sharpness`, type has to be `int`")

        self._sharpness = sharpness

    @property
    def min_gop(self):
        # type: () -> int
        """Gets the min_gop of this Vp9VideoConfiguration.

        Minimum GOP length, the minimum distance between I-frames.

        :return: The min_gop of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._min_gop

    @min_gop.setter
    def min_gop(self, min_gop):
        # type: (int) -> None
        """Sets the min_gop of this Vp9VideoConfiguration.

        Minimum GOP length, the minimum distance between I-frames.

        :param min_gop: The min_gop of this Vp9VideoConfiguration.
        :type: int
        """

        if min_gop is not None:
            if not isinstance(min_gop, int):
                raise TypeError("Invalid type for `min_gop`, type has to be `int`")

        self._min_gop = min_gop

    @property
    def max_gop(self):
        # type: () -> int
        """Gets the max_gop of this Vp9VideoConfiguration.

        Maximum GOP length, the maximum distance between I-frames

        :return: The max_gop of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._max_gop

    @max_gop.setter
    def max_gop(self, max_gop):
        # type: (int) -> None
        """Sets the max_gop of this Vp9VideoConfiguration.

        Maximum GOP length, the maximum distance between I-frames

        :param max_gop: The max_gop of this Vp9VideoConfiguration.
        :type: int
        """

        if max_gop is not None:
            if not isinstance(max_gop, int):
                raise TypeError("Invalid type for `max_gop`, type has to be `int`")

        self._max_gop = max_gop

    @property
    def min_keyframe_interval(self):
        # type: () -> float
        """Gets the min_keyframe_interval of this Vp9VideoConfiguration.

        Minimum interval in seconds between key frames

        :return: The min_keyframe_interval of this Vp9VideoConfiguration.
        :rtype: float
        """
        return self._min_keyframe_interval

    @min_keyframe_interval.setter
    def min_keyframe_interval(self, min_keyframe_interval):
        # type: (float) -> None
        """Sets the min_keyframe_interval of this Vp9VideoConfiguration.

        Minimum interval in seconds between key frames

        :param min_keyframe_interval: The min_keyframe_interval of this Vp9VideoConfiguration.
        :type: float
        """

        if min_keyframe_interval is not None:
            if not isinstance(min_keyframe_interval, (float, int)):
                raise TypeError("Invalid type for `min_keyframe_interval`, type has to be `float`")

        self._min_keyframe_interval = min_keyframe_interval

    @property
    def max_keyframe_interval(self):
        # type: () -> float
        """Gets the max_keyframe_interval of this Vp9VideoConfiguration.

        Maximum interval in seconds between key frames

        :return: The max_keyframe_interval of this Vp9VideoConfiguration.
        :rtype: float
        """
        return self._max_keyframe_interval

    @max_keyframe_interval.setter
    def max_keyframe_interval(self, max_keyframe_interval):
        # type: (float) -> None
        """Sets the max_keyframe_interval of this Vp9VideoConfiguration.

        Maximum interval in seconds between key frames

        :param max_keyframe_interval: The max_keyframe_interval of this Vp9VideoConfiguration.
        :type: float
        """

        if max_keyframe_interval is not None:
            if not isinstance(max_keyframe_interval, (float, int)):
                raise TypeError("Invalid type for `max_keyframe_interval`, type has to be `float`")

        self._max_keyframe_interval = max_keyframe_interval

    @property
    def quality(self):
        # type: () -> Vp9Quality
        """Gets the quality of this Vp9VideoConfiguration.


        :return: The quality of this Vp9VideoConfiguration.
        :rtype: Vp9Quality
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        # type: (Vp9Quality) -> None
        """Sets the quality of this Vp9VideoConfiguration.


        :param quality: The quality of this Vp9VideoConfiguration.
        :type: Vp9Quality
        """

        if quality is not None:
            if not isinstance(quality, Vp9Quality):
                raise TypeError("Invalid type for `quality`, type has to be `Vp9Quality`")

        self._quality = quality

    @property
    def lossless(self):
        # type: () -> bool
        """Gets the lossless of this Vp9VideoConfiguration.

        Lossless mode

        :return: The lossless of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._lossless

    @lossless.setter
    def lossless(self, lossless):
        # type: (bool) -> None
        """Sets the lossless of this Vp9VideoConfiguration.

        Lossless mode

        :param lossless: The lossless of this Vp9VideoConfiguration.
        :type: bool
        """

        if lossless is not None:
            if not isinstance(lossless, bool):
                raise TypeError("Invalid type for `lossless`, type has to be `bool`")

        self._lossless = lossless

    @property
    def static_thresh(self):
        # type: () -> int
        """Gets the static_thresh of this Vp9VideoConfiguration.

        A change threshold on blocks below which they will be skipped by the encoder.

        :return: The static_thresh of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._static_thresh

    @static_thresh.setter
    def static_thresh(self, static_thresh):
        # type: (int) -> None
        """Sets the static_thresh of this Vp9VideoConfiguration.

        A change threshold on blocks below which they will be skipped by the encoder.

        :param static_thresh: The static_thresh of this Vp9VideoConfiguration.
        :type: int
        """

        if static_thresh is not None:
            if static_thresh is not None and static_thresh < 0:
                raise ValueError("Invalid value for `static_thresh`, must be a value greater than or equal to `0`")
            if not isinstance(static_thresh, int):
                raise TypeError("Invalid type for `static_thresh`, type has to be `int`")

        self._static_thresh = static_thresh

    @property
    def aq_mode(self):
        # type: () -> Vp9AqMode
        """Gets the aq_mode of this Vp9VideoConfiguration.


        :return: The aq_mode of this Vp9VideoConfiguration.
        :rtype: Vp9AqMode
        """
        return self._aq_mode

    @aq_mode.setter
    def aq_mode(self, aq_mode):
        # type: (Vp9AqMode) -> None
        """Sets the aq_mode of this Vp9VideoConfiguration.


        :param aq_mode: The aq_mode of this Vp9VideoConfiguration.
        :type: Vp9AqMode
        """

        if aq_mode is not None:
            if not isinstance(aq_mode, Vp9AqMode):
                raise TypeError("Invalid type for `aq_mode`, type has to be `Vp9AqMode`")

        self._aq_mode = aq_mode

    @property
    def arnr_max_frames(self):
        # type: () -> int
        """Gets the arnr_max_frames of this Vp9VideoConfiguration.

        altref noise reduction max frame count.

        :return: The arnr_max_frames of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._arnr_max_frames

    @arnr_max_frames.setter
    def arnr_max_frames(self, arnr_max_frames):
        # type: (int) -> None
        """Sets the arnr_max_frames of this Vp9VideoConfiguration.

        altref noise reduction max frame count.

        :param arnr_max_frames: The arnr_max_frames of this Vp9VideoConfiguration.
        :type: int
        """

        if arnr_max_frames is not None:
            if arnr_max_frames is not None and arnr_max_frames > 15:
                raise ValueError("Invalid value for `arnr_max_frames`, must be a value less than or equal to `15`")
            if arnr_max_frames is not None and arnr_max_frames < 0:
                raise ValueError("Invalid value for `arnr_max_frames`, must be a value greater than or equal to `0`")
            if not isinstance(arnr_max_frames, int):
                raise TypeError("Invalid type for `arnr_max_frames`, type has to be `int`")

        self._arnr_max_frames = arnr_max_frames

    @property
    def arnr_strength(self):
        # type: () -> int
        """Gets the arnr_strength of this Vp9VideoConfiguration.

        altref noise reduction filter strength.

        :return: The arnr_strength of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._arnr_strength

    @arnr_strength.setter
    def arnr_strength(self, arnr_strength):
        # type: (int) -> None
        """Sets the arnr_strength of this Vp9VideoConfiguration.

        altref noise reduction filter strength.

        :param arnr_strength: The arnr_strength of this Vp9VideoConfiguration.
        :type: int
        """

        if arnr_strength is not None:
            if arnr_strength is not None and arnr_strength > 6:
                raise ValueError("Invalid value for `arnr_strength`, must be a value less than or equal to `6`")
            if arnr_strength is not None and arnr_strength < 0:
                raise ValueError("Invalid value for `arnr_strength`, must be a value greater than or equal to `0`")
            if not isinstance(arnr_strength, int):
                raise TypeError("Invalid type for `arnr_strength`, type has to be `int`")

        self._arnr_strength = arnr_strength

    @property
    def arnr_type(self):
        # type: () -> Vp9ArnrType
        """Gets the arnr_type of this Vp9VideoConfiguration.


        :return: The arnr_type of this Vp9VideoConfiguration.
        :rtype: Vp9ArnrType
        """
        return self._arnr_type

    @arnr_type.setter
    def arnr_type(self, arnr_type):
        # type: (Vp9ArnrType) -> None
        """Sets the arnr_type of this Vp9VideoConfiguration.


        :param arnr_type: The arnr_type of this Vp9VideoConfiguration.
        :type: Vp9ArnrType
        """

        if arnr_type is not None:
            if not isinstance(arnr_type, Vp9ArnrType):
                raise TypeError("Invalid type for `arnr_type`, type has to be `Vp9ArnrType`")

        self._arnr_type = arnr_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Vp9VideoConfiguration, self), "to_dict"):
            result = super(Vp9VideoConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Vp9VideoConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.audio_group_configuration import AudioGroupConfiguration
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint
import six


class StreamInfo(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 audio=None,
                 audio_groups=None,
                 video=None,
                 subtitles=None,
                 closed_captions=None,
                 encoding_id=None,
                 stream_id=None,
                 muxing_id=None,
                 drm_id=None,
                 segment_path=None,
                 uri=None,
                 start_segment_number=None,
                 end_segment_number=None,
                 force_frame_rate_attribute=None,
                 force_video_range_attribute=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, AudioGroupConfiguration, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, int, int, bool, bool) -> None
        super(StreamInfo, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._audio = None
        self._audio_groups = None
        self._video = None
        self._subtitles = None
        self._closed_captions = None
        self._encoding_id = None
        self._stream_id = None
        self._muxing_id = None
        self._drm_id = None
        self._segment_path = None
        self._uri = None
        self._start_segment_number = None
        self._end_segment_number = None
        self._force_frame_rate_attribute = None
        self._force_video_range_attribute = None
        self.discriminator = None

        if audio is not None:
            self.audio = audio
        if audio_groups is not None:
            self.audio_groups = audio_groups
        if video is not None:
            self.video = video
        if subtitles is not None:
            self.subtitles = subtitles
        if closed_captions is not None:
            self.closed_captions = closed_captions
        if encoding_id is not None:
            self.encoding_id = encoding_id
        if stream_id is not None:
            self.stream_id = stream_id
        if muxing_id is not None:
            self.muxing_id = muxing_id
        if drm_id is not None:
            self.drm_id = drm_id
        if segment_path is not None:
            self.segment_path = segment_path
        if uri is not None:
            self.uri = uri
        if start_segment_number is not None:
            self.start_segment_number = start_segment_number
        if end_segment_number is not None:
            self.end_segment_number = end_segment_number
        if force_frame_rate_attribute is not None:
            self.force_frame_rate_attribute = force_frame_rate_attribute
        if force_video_range_attribute is not None:
            self.force_video_range_attribute = force_video_range_attribute

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(StreamInfo, self), 'openapi_types'):
            types = getattr(super(StreamInfo, self), 'openapi_types')

        types.update({
            'audio': 'string_types',
            'audio_groups': 'AudioGroupConfiguration',
            'video': 'string_types',
            'subtitles': 'string_types',
            'closed_captions': 'string_types',
            'encoding_id': 'string_types',
            'stream_id': 'string_types',
            'muxing_id': 'string_types',
            'drm_id': 'string_types',
            'segment_path': 'string_types',
            'uri': 'string_types',
            'start_segment_number': 'int',
            'end_segment_number': 'int',
            'force_frame_rate_attribute': 'bool',
            'force_video_range_attribute': 'bool'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(StreamInfo, self), 'attribute_map'):
            attributes = getattr(super(StreamInfo, self), 'attribute_map')

        attributes.update({
            'audio': 'audio',
            'audio_groups': 'audioGroups',
            'video': 'video',
            'subtitles': 'subtitles',
            'closed_captions': 'closedCaptions',
            'encoding_id': 'encodingId',
            'stream_id': 'streamId',
            'muxing_id': 'muxingId',
            'drm_id': 'drmId',
            'segment_path': 'segmentPath',
            'uri': 'uri',
            'start_segment_number': 'startSegmentNumber',
            'end_segment_number': 'endSegmentNumber',
            'force_frame_rate_attribute': 'forceFrameRateAttribute',
            'force_video_range_attribute': 'forceVideoRangeAttribute'
        })
        return attributes

    @property
    def audio(self):
        # type: () -> string_types
        """Gets the audio of this StreamInfo.

        It MUST match the value of the GROUP-ID attribute of an Audio EXT-X-MEDIA tag elsewhere in the Master Playlist. Either this or `audioGroups` must be set.

        :return: The audio of this StreamInfo.
        :rtype: string_types
        """
        return self._audio

    @audio.setter
    def audio(self, audio):
        # type: (string_types) -> None
        """Sets the audio of this StreamInfo.

        It MUST match the value of the GROUP-ID attribute of an Audio EXT-X-MEDIA tag elsewhere in the Master Playlist. Either this or `audioGroups` must be set.

        :param audio: The audio of this StreamInfo.
        :type: string_types
        """

        if audio is not None:
            if not isinstance(audio, string_types):
                raise TypeError("Invalid type for `audio`, type has to be `string_types`")

        self._audio = audio

    @property
    def audio_groups(self):
        # type: () -> AudioGroupConfiguration
        """Gets the audio_groups of this StreamInfo.

        HLS Audio Group Configuration. You will want to use this configuration property in case you specify conditions on audio streams. The first matching audio group will be used for the specific variant stream. Either this or `audio` must be set.

        :return: The audio_groups of this StreamInfo.
        :rtype: AudioGroupConfiguration
        """
        return self._audio_groups

    @audio_groups.setter
    def audio_groups(self, audio_groups):
        # type: (AudioGroupConfiguration) -> None
        """Sets the audio_groups of this StreamInfo.

        HLS Audio Group Configuration. You will want to use this configuration property in case you specify conditions on audio streams. The first matching audio group will be used for the specific variant stream. Either this or `audio` must be set.

        :param audio_groups: The audio_groups of this StreamInfo.
        :type: AudioGroupConfiguration
        """

        if audio_groups is not None:
            if not isinstance(audio_groups, AudioGroupConfiguration):
                raise TypeError("Invalid type for `audio_groups`, type has to be `AudioGroupConfiguration`")

        self._audio_groups = audio_groups

    @property
    def video(self):
        # type: () -> string_types
        """Gets the video of this StreamInfo.

        It MUST match the value of the GROUP-ID attribute of a Video EXT-X-MEDIA tag elsewhere in the Master Playlist

        :return: The video of this StreamInfo.
        :rtype: string_types
        """
        return self._video

    @video.setter
    def video(self, video):
        # type: (string_types) -> None
        """Sets the video of this StreamInfo.

        It MUST match the value of the GROUP-ID attribute of a Video EXT-X-MEDIA tag elsewhere in the Master Playlist

        :param video: The video of this StreamInfo.
        :type: string_types
        """

        if video is not None:
            if not isinstance(video, string_types):
                raise TypeError("Invalid type for `video`, type has to be `string_types`")

        self._video = video

    @property
    def subtitles(self):
        # type: () -> string_types
        """Gets the subtitles of this StreamInfo.

        It MUST match the value of the GROUP-ID attribute of a Subtitles EXT-X-MEDIA tag elsewhere in the Master Playlist

        :return: The subtitles of this StreamInfo.
        :rtype: string_types
        """
        return self._subtitles

    @subtitles.setter
    def subtitles(self, subtitles):
        # type: (string_types) -> None
        """Sets the subtitles of this StreamInfo.

        It MUST match the value of the GROUP-ID attribute of a Subtitles EXT-X-MEDIA tag elsewhere in the Master Playlist

        :param subtitles: The subtitles of this StreamInfo.
        :type: string_types
        """

        if subtitles is not None:
            if not isinstance(subtitles, string_types):
                raise TypeError("Invalid type for `subtitles`, type has to be `string_types`")

        self._subtitles = subtitles

    @property
    def closed_captions(self):
        # type: () -> string_types
        """Gets the closed_captions of this StreamInfo.

        If the value is not 'NONE', it MUST match the value of the GROUP-ID attribute of a Closed Captions EXT-X-MEDIA tag elsewhere in the Playlist (required)

        :return: The closed_captions of this StreamInfo.
        :rtype: string_types
        """
        return self._closed_captions

    @closed_captions.setter
    def closed_captions(self, closed_captions):
        # type: (string_types) -> None
        """Sets the closed_captions of this StreamInfo.

        If the value is not 'NONE', it MUST match the value of the GROUP-ID attribute of a Closed Captions EXT-X-MEDIA tag elsewhere in the Playlist (required)

        :param closed_captions: The closed_captions of this StreamInfo.
        :type: string_types
        """

        if closed_captions is not None:
            if not isinstance(closed_captions, string_types):
                raise TypeError("Invalid type for `closed_captions`, type has to be `string_types`")

        self._closed_captions = closed_captions

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this StreamInfo.

        Id of the encoding. (required)

        :return: The encoding_id of this StreamInfo.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this StreamInfo.

        Id of the encoding. (required)

        :param encoding_id: The encoding_id of this StreamInfo.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def stream_id(self):
        # type: () -> string_types
        """Gets the stream_id of this StreamInfo.

        Id of the stream. (required)

        :return: The stream_id of this StreamInfo.
        :rtype: string_types
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        # type: (string_types) -> None
        """Sets the stream_id of this StreamInfo.

        Id of the stream. (required)

        :param stream_id: The stream_id of this StreamInfo.
        :type: string_types
        """

        if stream_id is not None:
            if not isinstance(stream_id, string_types):
                raise TypeError("Invalid type for `stream_id`, type has to be `string_types`")

        self._stream_id = stream_id

    @property
    def muxing_id(self):
        # type: () -> string_types
        """Gets the muxing_id of this StreamInfo.

        Id of the muxing. (required)

        :return: The muxing_id of this StreamInfo.
        :rtype: string_types
        """
        return self._muxing_id

    @muxing_id.setter
    def muxing_id(self, muxing_id):
        # type: (string_types) -> None
        """Sets the muxing_id of this StreamInfo.

        Id of the muxing. (required)

        :param muxing_id: The muxing_id of this StreamInfo.
        :type: string_types
        """

        if muxing_id is not None:
            if not isinstance(muxing_id, string_types):
                raise TypeError("Invalid type for `muxing_id`, type has to be `string_types`")

        self._muxing_id = muxing_id

    @property
    def drm_id(self):
        # type: () -> string_types
        """Gets the drm_id of this StreamInfo.

        Id of the DRM.

        :return: The drm_id of this StreamInfo.
        :rtype: string_types
        """
        return self._drm_id

    @drm_id.setter
    def drm_id(self, drm_id):
        # type: (string_types) -> None
        """Sets the drm_id of this StreamInfo.

        Id of the DRM.

        :param drm_id: The drm_id of this StreamInfo.
        :type: string_types
        """

        if drm_id is not None:
            if not isinstance(drm_id, string_types):
                raise TypeError("Invalid type for `drm_id`, type has to be `string_types`")

        self._drm_id = drm_id

    @property
    def segment_path(self):
        # type: () -> string_types
        """Gets the segment_path of this StreamInfo.

        Path to segments. (required)

        :return: The segment_path of this StreamInfo.
        :rtype: string_types
        """
        return self._segment_path

    @segment_path.setter
    def segment_path(self, segment_path):
        # type: (string_types) -> None
        """Sets the segment_path of this StreamInfo.

        Path to segments. (required)

        :param segment_path: The segment_path of this StreamInfo.
        :type: string_types
        """

        if segment_path is not None:
            if not isinstance(segment_path, string_types):
                raise TypeError("Invalid type for `segment_path`, type has to be `string_types`")

        self._segment_path = segment_path

    @property
    def uri(self):
        # type: () -> string_types
        """Gets the uri of this StreamInfo.

        The URI of the playlist file. (required)

        :return: The uri of this StreamInfo.
        :rtype: string_types
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        # type: (string_types) -> None
        """Sets the uri of this StreamInfo.

        The URI of the playlist file. (required)

        :param uri: The uri of this StreamInfo.
        :type: string_types
        """

        if uri is not None:
            if not isinstance(uri, string_types):
                raise TypeError("Invalid type for `uri`, type has to be `string_types`")

        self._uri = uri

    @property
    def start_segment_number(self):
        # type: () -> int
        """Gets the start_segment_number of this StreamInfo.

        Number of the first segment. Default is 0.

        :return: The start_segment_number of this StreamInfo.
        :rtype: int
        """
        return self._start_segment_number

    @start_segment_number.setter
    def start_segment_number(self, start_segment_number):
        # type: (int) -> None
        """Sets the start_segment_number of this StreamInfo.

        Number of the first segment. Default is 0.

        :param start_segment_number: The start_segment_number of this StreamInfo.
        :type: int
        """

        if start_segment_number is not None:
            if not isinstance(start_segment_number, int):
                raise TypeError("Invalid type for `start_segment_number`, type has to be `int`")

        self._start_segment_number = start_segment_number

    @property
    def end_segment_number(self):
        # type: () -> int
        """Gets the end_segment_number of this StreamInfo.

        Number of the last segment. Default is the last one that was encoded.

        :return: The end_segment_number of this StreamInfo.
        :rtype: int
        """
        return self._end_segment_number

    @end_segment_number.setter
    def end_segment_number(self, end_segment_number):
        # type: (int) -> None
        """Sets the end_segment_number of this StreamInfo.

        Number of the last segment. Default is the last one that was encoded.

        :param end_segment_number: The end_segment_number of this StreamInfo.
        :type: int
        """

        if end_segment_number is not None:
            if not isinstance(end_segment_number, int):
                raise TypeError("Invalid type for `end_segment_number`, type has to be `int`")

        self._end_segment_number = end_segment_number

    @property
    def force_frame_rate_attribute(self):
        # type: () -> bool
        """Gets the force_frame_rate_attribute of this StreamInfo.

        Force the addition of the frame rate attribute to all stream infos.

        :return: The force_frame_rate_attribute of this StreamInfo.
        :rtype: bool
        """
        return self._force_frame_rate_attribute

    @force_frame_rate_attribute.setter
    def force_frame_rate_attribute(self, force_frame_rate_attribute):
        # type: (bool) -> None
        """Sets the force_frame_rate_attribute of this StreamInfo.

        Force the addition of the frame rate attribute to all stream infos.

        :param force_frame_rate_attribute: The force_frame_rate_attribute of this StreamInfo.
        :type: bool
        """

        if force_frame_rate_attribute is not None:
            if not isinstance(force_frame_rate_attribute, bool):
                raise TypeError("Invalid type for `force_frame_rate_attribute`, type has to be `bool`")

        self._force_frame_rate_attribute = force_frame_rate_attribute

    @property
    def force_video_range_attribute(self):
        # type: () -> bool
        """Gets the force_video_range_attribute of this StreamInfo.

        Force the addition of the video-range attribute to all stream infos.

        :return: The force_video_range_attribute of this StreamInfo.
        :rtype: bool
        """
        return self._force_video_range_attribute

    @force_video_range_attribute.setter
    def force_video_range_attribute(self, force_video_range_attribute):
        # type: (bool) -> None
        """Sets the force_video_range_attribute of this StreamInfo.

        Force the addition of the video-range attribute to all stream infos.

        :param force_video_range_attribute: The force_video_range_attribute of this StreamInfo.
        :type: bool
        """

        if force_video_range_attribute is not None:
            if not isinstance(force_video_range_attribute, bool):
                raise TypeError("Invalid type for `force_video_range_attribute`, type has to be `bool`")

        self._force_video_range_attribute = force_video_range_attribute

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(StreamInfo, self), "to_dict"):
            result = super(StreamInfo, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class Link(object):
    @poscheck_model
    def __init__(self,
                 href=None,
                 title=None):
        # type: (string_types, string_types) -> None

        self._href = None
        self._title = None
        self.discriminator = None

        if href is not None:
            self.href = href
        if title is not None:
            self.title = title

    @property
    def openapi_types(self):
        types = {
            'href': 'string_types',
            'title': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'href': 'href',
            'title': 'title'
        }
        return attributes

    @property
    def href(self):
        # type: () -> string_types
        """Gets the href of this Link.

        webpage target URL (required)

        :return: The href of this Link.
        :rtype: string_types
        """
        return self._href

    @href.setter
    def href(self, href):
        # type: (string_types) -> None
        """Sets the href of this Link.

        webpage target URL (required)

        :param href: The href of this Link.
        :type: string_types
        """

        if href is not None:
            if not isinstance(href, string_types):
                raise TypeError("Invalid type for `href`, type has to be `string_types`")

        self._href = href

    @property
    def title(self):
        # type: () -> string_types
        """Gets the title of this Link.

        Short description of the linked page

        :return: The title of this Link.
        :rtype: string_types
        """
        return self._title

    @title.setter
    def title(self, title):
        # type: (string_types) -> None
        """Sets the title of this Link.

        Short description of the linked page

        :param title: The title of this Link.
        :type: string_types
        """

        if title is not None:
            if not isinstance(title, string_types):
                raise TypeError("Invalid type for `title`, type has to be `string_types`")

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Link):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_encoding_stats_event_details import LiveEncodingStatsEventDetails
import pprint
import six


class LiveEncodingStatsEvent(object):
    @poscheck_model
    def __init__(self,
                 time=None,
                 details=None):
        # type: (datetime, LiveEncodingStatsEventDetails) -> None

        self._time = None
        self._details = None
        self.discriminator = None

        if time is not None:
            self.time = time
        if details is not None:
            self.details = details

    @property
    def openapi_types(self):
        types = {
            'time': 'datetime',
            'details': 'LiveEncodingStatsEventDetails'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'time': 'time',
            'details': 'details'
        }
        return attributes

    @property
    def time(self):
        # type: () -> datetime
        """Gets the time of this LiveEncodingStatsEvent.

        Timestamp of the event, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ (required)

        :return: The time of this LiveEncodingStatsEvent.
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        # type: (datetime) -> None
        """Sets the time of this LiveEncodingStatsEvent.

        Timestamp of the event, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ (required)

        :param time: The time of this LiveEncodingStatsEvent.
        :type: datetime
        """

        if time is not None:
            if not isinstance(time, datetime):
                raise TypeError("Invalid type for `time`, type has to be `datetime`")

        self._time = time

    @property
    def details(self):
        # type: () -> LiveEncodingStatsEventDetails
        """Gets the details of this LiveEncodingStatsEvent.


        :return: The details of this LiveEncodingStatsEvent.
        :rtype: LiveEncodingStatsEventDetails
        """
        return self._details

    @details.setter
    def details(self, details):
        # type: (LiveEncodingStatsEventDetails) -> None
        """Sets the details of this LiveEncodingStatsEvent.


        :param details: The details of this LiveEncodingStatsEvent.
        :type: LiveEncodingStatsEventDetails
        """

        if details is not None:
            if not isinstance(details, LiveEncodingStatsEventDetails):
                raise TypeError("Invalid type for `details`, type has to be `LiveEncodingStatsEventDetails`")

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveEncodingStatsEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.statistics.encodings.vod.vod_api import VodApi
from bitmovin_api_sdk.encoding.statistics.encodings.vod.daily.daily_api import DailyApi
from bitmovin_api_sdk.encoding.statistics.encodings.vod.encoding_statistics_vod_list_query_params import EncodingStatisticsVodListQueryParams
from bitmovin_api_sdk.encoding.statistics.encodings.vod.encoding_statistics_vod_list_by_date_range_query_params import EncodingStatisticsVodListByDateRangeQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.color_config import ColorConfig
from bitmovin_api_sdk.models.display_aspect_ratio import DisplayAspectRatio
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.pixel_format import PixelFormat
from bitmovin_api_sdk.models.video_configuration import VideoConfiguration
from bitmovin_api_sdk.models.vp8_arnr_type import Vp8ArnrType
from bitmovin_api_sdk.models.vp8_noise_sensitivity import Vp8NoiseSensitivity
from bitmovin_api_sdk.models.vp8_quality import Vp8Quality
import pprint
import six


class Vp8VideoConfiguration(VideoConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 width=None,
                 height=None,
                 bitrate=None,
                 rate=None,
                 pixel_format=None,
                 color_config=None,
                 sample_aspect_ratio_numerator=None,
                 sample_aspect_ratio_denominator=None,
                 display_aspect_ratio=None,
                 encoding_mode=None,
                 crf=None,
                 lag_in_frames=None,
                 max_intra_rate=None,
                 qp_min=None,
                 qp_max=None,
                 rate_undershoot_pct=None,
                 rate_overshoot_pct=None,
                 cpu_used=None,
                 noise_sensitivity=None,
                 sharpness=None,
                 min_gop=None,
                 max_gop=None,
                 min_keyframe_interval=None,
                 max_keyframe_interval=None,
                 quality=None,
                 static_thresh=None,
                 arnr_max_frames=None,
                 arnr_strength=None,
                 arnr_type=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, int, float, PixelFormat, ColorConfig, int, int, DisplayAspectRatio, EncodingMode, int, int, int, int, int, int, int, int, Vp8NoiseSensitivity, int, int, int, float, float, Vp8Quality, int, int, int, Vp8ArnrType) -> None
        super(Vp8VideoConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, width=width, height=height, bitrate=bitrate, rate=rate, pixel_format=pixel_format, color_config=color_config, sample_aspect_ratio_numerator=sample_aspect_ratio_numerator, sample_aspect_ratio_denominator=sample_aspect_ratio_denominator, display_aspect_ratio=display_aspect_ratio, encoding_mode=encoding_mode)

        self._crf = None
        self._lag_in_frames = None
        self._max_intra_rate = None
        self._qp_min = None
        self._qp_max = None
        self._rate_undershoot_pct = None
        self._rate_overshoot_pct = None
        self._cpu_used = None
        self._noise_sensitivity = None
        self._sharpness = None
        self._min_gop = None
        self._max_gop = None
        self._min_keyframe_interval = None
        self._max_keyframe_interval = None
        self._quality = None
        self._static_thresh = None
        self._arnr_max_frames = None
        self._arnr_strength = None
        self._arnr_type = None
        self.discriminator = None

        if crf is not None:
            self.crf = crf
        if lag_in_frames is not None:
            self.lag_in_frames = lag_in_frames
        if max_intra_rate is not None:
            self.max_intra_rate = max_intra_rate
        if qp_min is not None:
            self.qp_min = qp_min
        if qp_max is not None:
            self.qp_max = qp_max
        if rate_undershoot_pct is not None:
            self.rate_undershoot_pct = rate_undershoot_pct
        if rate_overshoot_pct is not None:
            self.rate_overshoot_pct = rate_overshoot_pct
        if cpu_used is not None:
            self.cpu_used = cpu_used
        if noise_sensitivity is not None:
            self.noise_sensitivity = noise_sensitivity
        if sharpness is not None:
            self.sharpness = sharpness
        if min_gop is not None:
            self.min_gop = min_gop
        if max_gop is not None:
            self.max_gop = max_gop
        if min_keyframe_interval is not None:
            self.min_keyframe_interval = min_keyframe_interval
        if max_keyframe_interval is not None:
            self.max_keyframe_interval = max_keyframe_interval
        if quality is not None:
            self.quality = quality
        if static_thresh is not None:
            self.static_thresh = static_thresh
        if arnr_max_frames is not None:
            self.arnr_max_frames = arnr_max_frames
        if arnr_strength is not None:
            self.arnr_strength = arnr_strength
        if arnr_type is not None:
            self.arnr_type = arnr_type

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Vp8VideoConfiguration, self), 'openapi_types'):
            types = getattr(super(Vp8VideoConfiguration, self), 'openapi_types')

        types.update({
            'crf': 'int',
            'lag_in_frames': 'int',
            'max_intra_rate': 'int',
            'qp_min': 'int',
            'qp_max': 'int',
            'rate_undershoot_pct': 'int',
            'rate_overshoot_pct': 'int',
            'cpu_used': 'int',
            'noise_sensitivity': 'Vp8NoiseSensitivity',
            'sharpness': 'int',
            'min_gop': 'int',
            'max_gop': 'int',
            'min_keyframe_interval': 'float',
            'max_keyframe_interval': 'float',
            'quality': 'Vp8Quality',
            'static_thresh': 'int',
            'arnr_max_frames': 'int',
            'arnr_strength': 'int',
            'arnr_type': 'Vp8ArnrType'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Vp8VideoConfiguration, self), 'attribute_map'):
            attributes = getattr(super(Vp8VideoConfiguration, self), 'attribute_map')

        attributes.update({
            'crf': 'crf',
            'lag_in_frames': 'lagInFrames',
            'max_intra_rate': 'maxIntraRate',
            'qp_min': 'qpMin',
            'qp_max': 'qpMax',
            'rate_undershoot_pct': 'rateUndershootPct',
            'rate_overshoot_pct': 'rateOvershootPct',
            'cpu_used': 'cpuUsed',
            'noise_sensitivity': 'noiseSensitivity',
            'sharpness': 'sharpness',
            'min_gop': 'minGop',
            'max_gop': 'maxGop',
            'min_keyframe_interval': 'minKeyframeInterval',
            'max_keyframe_interval': 'maxKeyframeInterval',
            'quality': 'quality',
            'static_thresh': 'staticThresh',
            'arnr_max_frames': 'arnrMaxFrames',
            'arnr_strength': 'arnrStrength',
            'arnr_type': 'arnrType'
        })
        return attributes

    @property
    def crf(self):
        # type: () -> int
        """Gets the crf of this Vp8VideoConfiguration.

        Constant rate factor for quality-based variable bitrate. Either bitrate or crf is required.

        :return: The crf of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._crf

    @crf.setter
    def crf(self, crf):
        # type: (int) -> None
        """Sets the crf of this Vp8VideoConfiguration.

        Constant rate factor for quality-based variable bitrate. Either bitrate or crf is required.

        :param crf: The crf of this Vp8VideoConfiguration.
        :type: int
        """

        if crf is not None:
            if crf is not None and crf > 63:
                raise ValueError("Invalid value for `crf`, must be a value less than or equal to `63`")
            if crf is not None and crf < 0:
                raise ValueError("Invalid value for `crf`, must be a value greater than or equal to `0`")
            if not isinstance(crf, int):
                raise TypeError("Invalid type for `crf`, type has to be `int`")

        self._crf = crf

    @property
    def lag_in_frames(self):
        # type: () -> int
        """Gets the lag_in_frames of this Vp8VideoConfiguration.

        Number of frames to look ahead for alternate reference frame selection.

        :return: The lag_in_frames of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._lag_in_frames

    @lag_in_frames.setter
    def lag_in_frames(self, lag_in_frames):
        # type: (int) -> None
        """Sets the lag_in_frames of this Vp8VideoConfiguration.

        Number of frames to look ahead for alternate reference frame selection.

        :param lag_in_frames: The lag_in_frames of this Vp8VideoConfiguration.
        :type: int
        """

        if lag_in_frames is not None:
            if lag_in_frames is not None and lag_in_frames > 25:
                raise ValueError("Invalid value for `lag_in_frames`, must be a value less than or equal to `25`")
            if lag_in_frames is not None and lag_in_frames < 0:
                raise ValueError("Invalid value for `lag_in_frames`, must be a value greater than or equal to `0`")
            if not isinstance(lag_in_frames, int):
                raise TypeError("Invalid type for `lag_in_frames`, type has to be `int`")

        self._lag_in_frames = lag_in_frames

    @property
    def max_intra_rate(self):
        # type: () -> int
        """Gets the max_intra_rate of this Vp8VideoConfiguration.

        Maximum I-frame bitrate (percentage) 0=unlimited

        :return: The max_intra_rate of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._max_intra_rate

    @max_intra_rate.setter
    def max_intra_rate(self, max_intra_rate):
        # type: (int) -> None
        """Sets the max_intra_rate of this Vp8VideoConfiguration.

        Maximum I-frame bitrate (percentage) 0=unlimited

        :param max_intra_rate: The max_intra_rate of this Vp8VideoConfiguration.
        :type: int
        """

        if max_intra_rate is not None:
            if not isinstance(max_intra_rate, int):
                raise TypeError("Invalid type for `max_intra_rate`, type has to be `int`")

        self._max_intra_rate = max_intra_rate

    @property
    def qp_min(self):
        # type: () -> int
        """Gets the qp_min of this Vp8VideoConfiguration.

        Minimum quantization factor.

        :return: The qp_min of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._qp_min

    @qp_min.setter
    def qp_min(self, qp_min):
        # type: (int) -> None
        """Sets the qp_min of this Vp8VideoConfiguration.

        Minimum quantization factor.

        :param qp_min: The qp_min of this Vp8VideoConfiguration.
        :type: int
        """

        if qp_min is not None:
            if qp_min is not None and qp_min > 63:
                raise ValueError("Invalid value for `qp_min`, must be a value less than or equal to `63`")
            if qp_min is not None and qp_min < 0:
                raise ValueError("Invalid value for `qp_min`, must be a value greater than or equal to `0`")
            if not isinstance(qp_min, int):
                raise TypeError("Invalid type for `qp_min`, type has to be `int`")

        self._qp_min = qp_min

    @property
    def qp_max(self):
        # type: () -> int
        """Gets the qp_max of this Vp8VideoConfiguration.

        Maximum quantization factor.

        :return: The qp_max of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._qp_max

    @qp_max.setter
    def qp_max(self, qp_max):
        # type: (int) -> None
        """Sets the qp_max of this Vp8VideoConfiguration.

        Maximum quantization factor.

        :param qp_max: The qp_max of this Vp8VideoConfiguration.
        :type: int
        """

        if qp_max is not None:
            if qp_max is not None and qp_max > 63:
                raise ValueError("Invalid value for `qp_max`, must be a value less than or equal to `63`")
            if qp_max is not None and qp_max < 0:
                raise ValueError("Invalid value for `qp_max`, must be a value greater than or equal to `0`")
            if not isinstance(qp_max, int):
                raise TypeError("Invalid type for `qp_max`, type has to be `int`")

        self._qp_max = qp_max

    @property
    def rate_undershoot_pct(self):
        # type: () -> int
        """Gets the rate_undershoot_pct of this Vp8VideoConfiguration.

        Datarate undershoot (min) target (percentage).

        :return: The rate_undershoot_pct of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._rate_undershoot_pct

    @rate_undershoot_pct.setter
    def rate_undershoot_pct(self, rate_undershoot_pct):
        # type: (int) -> None
        """Sets the rate_undershoot_pct of this Vp8VideoConfiguration.

        Datarate undershoot (min) target (percentage).

        :param rate_undershoot_pct: The rate_undershoot_pct of this Vp8VideoConfiguration.
        :type: int
        """

        if rate_undershoot_pct is not None:
            if rate_undershoot_pct is not None and rate_undershoot_pct > 100:
                raise ValueError("Invalid value for `rate_undershoot_pct`, must be a value less than or equal to `100`")
            if rate_undershoot_pct is not None and rate_undershoot_pct < 0:
                raise ValueError("Invalid value for `rate_undershoot_pct`, must be a value greater than or equal to `0`")
            if not isinstance(rate_undershoot_pct, int):
                raise TypeError("Invalid type for `rate_undershoot_pct`, type has to be `int`")

        self._rate_undershoot_pct = rate_undershoot_pct

    @property
    def rate_overshoot_pct(self):
        # type: () -> int
        """Gets the rate_overshoot_pct of this Vp8VideoConfiguration.

        Datarate overshoot (max) target (percentage).

        :return: The rate_overshoot_pct of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._rate_overshoot_pct

    @rate_overshoot_pct.setter
    def rate_overshoot_pct(self, rate_overshoot_pct):
        # type: (int) -> None
        """Sets the rate_overshoot_pct of this Vp8VideoConfiguration.

        Datarate overshoot (max) target (percentage).

        :param rate_overshoot_pct: The rate_overshoot_pct of this Vp8VideoConfiguration.
        :type: int
        """

        if rate_overshoot_pct is not None:
            if rate_overshoot_pct is not None and rate_overshoot_pct > 100:
                raise ValueError("Invalid value for `rate_overshoot_pct`, must be a value less than or equal to `100`")
            if rate_overshoot_pct is not None and rate_overshoot_pct < 0:
                raise ValueError("Invalid value for `rate_overshoot_pct`, must be a value greater than or equal to `0`")
            if not isinstance(rate_overshoot_pct, int):
                raise TypeError("Invalid type for `rate_overshoot_pct`, type has to be `int`")

        self._rate_overshoot_pct = rate_overshoot_pct

    @property
    def cpu_used(self):
        # type: () -> int
        """Gets the cpu_used of this Vp8VideoConfiguration.


        :return: The cpu_used of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._cpu_used

    @cpu_used.setter
    def cpu_used(self, cpu_used):
        # type: (int) -> None
        """Sets the cpu_used of this Vp8VideoConfiguration.


        :param cpu_used: The cpu_used of this Vp8VideoConfiguration.
        :type: int
        """

        if cpu_used is not None:
            if not isinstance(cpu_used, int):
                raise TypeError("Invalid type for `cpu_used`, type has to be `int`")

        self._cpu_used = cpu_used

    @property
    def noise_sensitivity(self):
        # type: () -> Vp8NoiseSensitivity
        """Gets the noise_sensitivity of this Vp8VideoConfiguration.


        :return: The noise_sensitivity of this Vp8VideoConfiguration.
        :rtype: Vp8NoiseSensitivity
        """
        return self._noise_sensitivity

    @noise_sensitivity.setter
    def noise_sensitivity(self, noise_sensitivity):
        # type: (Vp8NoiseSensitivity) -> None
        """Sets the noise_sensitivity of this Vp8VideoConfiguration.


        :param noise_sensitivity: The noise_sensitivity of this Vp8VideoConfiguration.
        :type: Vp8NoiseSensitivity
        """

        if noise_sensitivity is not None:
            if not isinstance(noise_sensitivity, Vp8NoiseSensitivity):
                raise TypeError("Invalid type for `noise_sensitivity`, type has to be `Vp8NoiseSensitivity`")

        self._noise_sensitivity = noise_sensitivity

    @property
    def sharpness(self):
        # type: () -> int
        """Gets the sharpness of this Vp8VideoConfiguration.

        Loop filter sharpness.

        :return: The sharpness of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._sharpness

    @sharpness.setter
    def sharpness(self, sharpness):
        # type: (int) -> None
        """Sets the sharpness of this Vp8VideoConfiguration.

        Loop filter sharpness.

        :param sharpness: The sharpness of this Vp8VideoConfiguration.
        :type: int
        """

        if sharpness is not None:
            if sharpness is not None and sharpness > 7:
                raise ValueError("Invalid value for `sharpness`, must be a value less than or equal to `7`")
            if sharpness is not None and sharpness < 0:
                raise ValueError("Invalid value for `sharpness`, must be a value greater than or equal to `0`")
            if not isinstance(sharpness, int):
                raise TypeError("Invalid type for `sharpness`, type has to be `int`")

        self._sharpness = sharpness

    @property
    def min_gop(self):
        # type: () -> int
        """Gets the min_gop of this Vp8VideoConfiguration.

        Minimum GOP length, the minimum distance between I-frames.

        :return: The min_gop of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._min_gop

    @min_gop.setter
    def min_gop(self, min_gop):
        # type: (int) -> None
        """Sets the min_gop of this Vp8VideoConfiguration.

        Minimum GOP length, the minimum distance between I-frames.

        :param min_gop: The min_gop of this Vp8VideoConfiguration.
        :type: int
        """

        if min_gop is not None:
            if not isinstance(min_gop, int):
                raise TypeError("Invalid type for `min_gop`, type has to be `int`")

        self._min_gop = min_gop

    @property
    def max_gop(self):
        # type: () -> int
        """Gets the max_gop of this Vp8VideoConfiguration.

        Maximum GOP length, the maximum distance between I-frames

        :return: The max_gop of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._max_gop

    @max_gop.setter
    def max_gop(self, max_gop):
        # type: (int) -> None
        """Sets the max_gop of this Vp8VideoConfiguration.

        Maximum GOP length, the maximum distance between I-frames

        :param max_gop: The max_gop of this Vp8VideoConfiguration.
        :type: int
        """

        if max_gop is not None:
            if not isinstance(max_gop, int):
                raise TypeError("Invalid type for `max_gop`, type has to be `int`")

        self._max_gop = max_gop

    @property
    def min_keyframe_interval(self):
        # type: () -> float
        """Gets the min_keyframe_interval of this Vp8VideoConfiguration.

        Minimum interval in seconds between key frames

        :return: The min_keyframe_interval of this Vp8VideoConfiguration.
        :rtype: float
        """
        return self._min_keyframe_interval

    @min_keyframe_interval.setter
    def min_keyframe_interval(self, min_keyframe_interval):
        # type: (float) -> None
        """Sets the min_keyframe_interval of this Vp8VideoConfiguration.

        Minimum interval in seconds between key frames

        :param min_keyframe_interval: The min_keyframe_interval of this Vp8VideoConfiguration.
        :type: float
        """

        if min_keyframe_interval is not None:
            if not isinstance(min_keyframe_interval, (float, int)):
                raise TypeError("Invalid type for `min_keyframe_interval`, type has to be `float`")

        self._min_keyframe_interval = min_keyframe_interval

    @property
    def max_keyframe_interval(self):
        # type: () -> float
        """Gets the max_keyframe_interval of this Vp8VideoConfiguration.

        Maximum interval in seconds between key frames

        :return: The max_keyframe_interval of this Vp8VideoConfiguration.
        :rtype: float
        """
        return self._max_keyframe_interval

    @max_keyframe_interval.setter
    def max_keyframe_interval(self, max_keyframe_interval):
        # type: (float) -> None
        """Sets the max_keyframe_interval of this Vp8VideoConfiguration.

        Maximum interval in seconds between key frames

        :param max_keyframe_interval: The max_keyframe_interval of this Vp8VideoConfiguration.
        :type: float
        """

        if max_keyframe_interval is not None:
            if not isinstance(max_keyframe_interval, (float, int)):
                raise TypeError("Invalid type for `max_keyframe_interval`, type has to be `float`")

        self._max_keyframe_interval = max_keyframe_interval

    @property
    def quality(self):
        # type: () -> Vp8Quality
        """Gets the quality of this Vp8VideoConfiguration.


        :return: The quality of this Vp8VideoConfiguration.
        :rtype: Vp8Quality
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        # type: (Vp8Quality) -> None
        """Sets the quality of this Vp8VideoConfiguration.


        :param quality: The quality of this Vp8VideoConfiguration.
        :type: Vp8Quality
        """

        if quality is not None:
            if not isinstance(quality, Vp8Quality):
                raise TypeError("Invalid type for `quality`, type has to be `Vp8Quality`")

        self._quality = quality

    @property
    def static_thresh(self):
        # type: () -> int
        """Gets the static_thresh of this Vp8VideoConfiguration.

        A change threshold on blocks below which they will be skipped by the encoder.

        :return: The static_thresh of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._static_thresh

    @static_thresh.setter
    def static_thresh(self, static_thresh):
        # type: (int) -> None
        """Sets the static_thresh of this Vp8VideoConfiguration.

        A change threshold on blocks below which they will be skipped by the encoder.

        :param static_thresh: The static_thresh of this Vp8VideoConfiguration.
        :type: int
        """

        if static_thresh is not None:
            if static_thresh is not None and static_thresh < 0:
                raise ValueError("Invalid value for `static_thresh`, must be a value greater than or equal to `0`")
            if not isinstance(static_thresh, int):
                raise TypeError("Invalid type for `static_thresh`, type has to be `int`")

        self._static_thresh = static_thresh

    @property
    def arnr_max_frames(self):
        # type: () -> int
        """Gets the arnr_max_frames of this Vp8VideoConfiguration.

        altref noise reduction max frame count.

        :return: The arnr_max_frames of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._arnr_max_frames

    @arnr_max_frames.setter
    def arnr_max_frames(self, arnr_max_frames):
        # type: (int) -> None
        """Sets the arnr_max_frames of this Vp8VideoConfiguration.

        altref noise reduction max frame count.

        :param arnr_max_frames: The arnr_max_frames of this Vp8VideoConfiguration.
        :type: int
        """

        if arnr_max_frames is not None:
            if arnr_max_frames is not None and arnr_max_frames > 15:
                raise ValueError("Invalid value for `arnr_max_frames`, must be a value less than or equal to `15`")
            if arnr_max_frames is not None and arnr_max_frames < 0:
                raise ValueError("Invalid value for `arnr_max_frames`, must be a value greater than or equal to `0`")
            if not isinstance(arnr_max_frames, int):
                raise TypeError("Invalid type for `arnr_max_frames`, type has to be `int`")

        self._arnr_max_frames = arnr_max_frames

    @property
    def arnr_strength(self):
        # type: () -> int
        """Gets the arnr_strength of this Vp8VideoConfiguration.

        altref noise reduction filter strength.

        :return: The arnr_strength of this Vp8VideoConfiguration.
        :rtype: int
        """
        return self._arnr_strength

    @arnr_strength.setter
    def arnr_strength(self, arnr_strength):
        # type: (int) -> None
        """Sets the arnr_strength of this Vp8VideoConfiguration.

        altref noise reduction filter strength.

        :param arnr_strength: The arnr_strength of this Vp8VideoConfiguration.
        :type: int
        """

        if arnr_strength is not None:
            if arnr_strength is not None and arnr_strength > 6:
                raise ValueError("Invalid value for `arnr_strength`, must be a value less than or equal to `6`")
            if arnr_strength is not None and arnr_strength < 0:
                raise ValueError("Invalid value for `arnr_strength`, must be a value greater than or equal to `0`")
            if not isinstance(arnr_strength, int):
                raise TypeError("Invalid type for `arnr_strength`, type has to be `int`")

        self._arnr_strength = arnr_strength

    @property
    def arnr_type(self):
        # type: () -> Vp8ArnrType
        """Gets the arnr_type of this Vp8VideoConfiguration.


        :return: The arnr_type of this Vp8VideoConfiguration.
        :rtype: Vp8ArnrType
        """
        return self._arnr_type

    @arnr_type.setter
    def arnr_type(self, arnr_type):
        # type: (Vp8ArnrType) -> None
        """Sets the arnr_type of this Vp8VideoConfiguration.


        :param arnr_type: The arnr_type of this Vp8VideoConfiguration.
        :type: Vp8ArnrType
        """

        if arnr_type is not None:
            if not isinstance(arnr_type, Vp8ArnrType):
                raise TypeError("Invalid type for `arnr_type`, type has to be `Vp8ArnrType`")

        self._arnr_type = arnr_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Vp8VideoConfiguration, self), "to_dict"):
            result = super(Vp8VideoConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Vp8VideoConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.chroma_location import ChromaLocation
from bitmovin_api_sdk.models.color_primaries import ColorPrimaries
from bitmovin_api_sdk.models.color_range import ColorRange
from bitmovin_api_sdk.models.color_space import ColorSpace
from bitmovin_api_sdk.models.color_transfer import ColorTransfer
from bitmovin_api_sdk.models.input_color_primaries import InputColorPrimaries
from bitmovin_api_sdk.models.input_color_range import InputColorRange
from bitmovin_api_sdk.models.input_color_space import InputColorSpace
from bitmovin_api_sdk.models.input_color_transfer import InputColorTransfer
import pprint
import six


class ColorConfig(object):
    @poscheck_model
    def __init__(self,
                 copy_chroma_location_flag=None,
                 copy_color_space_flag=None,
                 copy_color_primaries_flag=None,
                 copy_color_range_flag=None,
                 copy_color_transfer_flag=None,
                 chroma_location=None,
                 color_space=None,
                 color_primaries=None,
                 color_range=None,
                 color_transfer=None,
                 input_color_space=None,
                 input_color_range=None,
                 input_color_primaries=None,
                 input_color_transfer=None):
        # type: (bool, bool, bool, bool, bool, ChromaLocation, ColorSpace, ColorPrimaries, ColorRange, ColorTransfer, InputColorSpace, InputColorRange, InputColorPrimaries, InputColorTransfer) -> None

        self._copy_chroma_location_flag = None
        self._copy_color_space_flag = None
        self._copy_color_primaries_flag = None
        self._copy_color_range_flag = None
        self._copy_color_transfer_flag = None
        self._chroma_location = None
        self._color_space = None
        self._color_primaries = None
        self._color_range = None
        self._color_transfer = None
        self._input_color_space = None
        self._input_color_range = None
        self._input_color_primaries = None
        self._input_color_transfer = None
        self.discriminator = None

        if copy_chroma_location_flag is not None:
            self.copy_chroma_location_flag = copy_chroma_location_flag
        if copy_color_space_flag is not None:
            self.copy_color_space_flag = copy_color_space_flag
        if copy_color_primaries_flag is not None:
            self.copy_color_primaries_flag = copy_color_primaries_flag
        if copy_color_range_flag is not None:
            self.copy_color_range_flag = copy_color_range_flag
        if copy_color_transfer_flag is not None:
            self.copy_color_transfer_flag = copy_color_transfer_flag
        if chroma_location is not None:
            self.chroma_location = chroma_location
        if color_space is not None:
            self.color_space = color_space
        if color_primaries is not None:
            self.color_primaries = color_primaries
        if color_range is not None:
            self.color_range = color_range
        if color_transfer is not None:
            self.color_transfer = color_transfer
        if input_color_space is not None:
            self.input_color_space = input_color_space
        if input_color_range is not None:
            self.input_color_range = input_color_range
        if input_color_primaries is not None:
            self.input_color_primaries = input_color_primaries
        if input_color_transfer is not None:
            self.input_color_transfer = input_color_transfer

    @property
    def openapi_types(self):
        types = {
            'copy_chroma_location_flag': 'bool',
            'copy_color_space_flag': 'bool',
            'copy_color_primaries_flag': 'bool',
            'copy_color_range_flag': 'bool',
            'copy_color_transfer_flag': 'bool',
            'chroma_location': 'ChromaLocation',
            'color_space': 'ColorSpace',
            'color_primaries': 'ColorPrimaries',
            'color_range': 'ColorRange',
            'color_transfer': 'ColorTransfer',
            'input_color_space': 'InputColorSpace',
            'input_color_range': 'InputColorRange',
            'input_color_primaries': 'InputColorPrimaries',
            'input_color_transfer': 'InputColorTransfer'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'copy_chroma_location_flag': 'copyChromaLocationFlag',
            'copy_color_space_flag': 'copyColorSpaceFlag',
            'copy_color_primaries_flag': 'copyColorPrimariesFlag',
            'copy_color_range_flag': 'copyColorRangeFlag',
            'copy_color_transfer_flag': 'copyColorTransferFlag',
            'chroma_location': 'chromaLocation',
            'color_space': 'colorSpace',
            'color_primaries': 'colorPrimaries',
            'color_range': 'colorRange',
            'color_transfer': 'colorTransfer',
            'input_color_space': 'inputColorSpace',
            'input_color_range': 'inputColorRange',
            'input_color_primaries': 'inputColorPrimaries',
            'input_color_transfer': 'inputColorTransfer'
        }
        return attributes

    @property
    def copy_chroma_location_flag(self):
        # type: () -> bool
        """Gets the copy_chroma_location_flag of this ColorConfig.

        Copy the chroma location setting from the input source

        :return: The copy_chroma_location_flag of this ColorConfig.
        :rtype: bool
        """
        return self._copy_chroma_location_flag

    @copy_chroma_location_flag.setter
    def copy_chroma_location_flag(self, copy_chroma_location_flag):
        # type: (bool) -> None
        """Sets the copy_chroma_location_flag of this ColorConfig.

        Copy the chroma location setting from the input source

        :param copy_chroma_location_flag: The copy_chroma_location_flag of this ColorConfig.
        :type: bool
        """

        if copy_chroma_location_flag is not None:
            if not isinstance(copy_chroma_location_flag, bool):
                raise TypeError("Invalid type for `copy_chroma_location_flag`, type has to be `bool`")

        self._copy_chroma_location_flag = copy_chroma_location_flag

    @property
    def copy_color_space_flag(self):
        # type: () -> bool
        """Gets the copy_color_space_flag of this ColorConfig.

        Copy the color space setting from the input source

        :return: The copy_color_space_flag of this ColorConfig.
        :rtype: bool
        """
        return self._copy_color_space_flag

    @copy_color_space_flag.setter
    def copy_color_space_flag(self, copy_color_space_flag):
        # type: (bool) -> None
        """Sets the copy_color_space_flag of this ColorConfig.

        Copy the color space setting from the input source

        :param copy_color_space_flag: The copy_color_space_flag of this ColorConfig.
        :type: bool
        """

        if copy_color_space_flag is not None:
            if not isinstance(copy_color_space_flag, bool):
                raise TypeError("Invalid type for `copy_color_space_flag`, type has to be `bool`")

        self._copy_color_space_flag = copy_color_space_flag

    @property
    def copy_color_primaries_flag(self):
        # type: () -> bool
        """Gets the copy_color_primaries_flag of this ColorConfig.

        Copy the color primaries setting from the input source

        :return: The copy_color_primaries_flag of this ColorConfig.
        :rtype: bool
        """
        return self._copy_color_primaries_flag

    @copy_color_primaries_flag.setter
    def copy_color_primaries_flag(self, copy_color_primaries_flag):
        # type: (bool) -> None
        """Sets the copy_color_primaries_flag of this ColorConfig.

        Copy the color primaries setting from the input source

        :param copy_color_primaries_flag: The copy_color_primaries_flag of this ColorConfig.
        :type: bool
        """

        if copy_color_primaries_flag is not None:
            if not isinstance(copy_color_primaries_flag, bool):
                raise TypeError("Invalid type for `copy_color_primaries_flag`, type has to be `bool`")

        self._copy_color_primaries_flag = copy_color_primaries_flag

    @property
    def copy_color_range_flag(self):
        # type: () -> bool
        """Gets the copy_color_range_flag of this ColorConfig.

        Copy the color range setting from the input source

        :return: The copy_color_range_flag of this ColorConfig.
        :rtype: bool
        """
        return self._copy_color_range_flag

    @copy_color_range_flag.setter
    def copy_color_range_flag(self, copy_color_range_flag):
        # type: (bool) -> None
        """Sets the copy_color_range_flag of this ColorConfig.

        Copy the color range setting from the input source

        :param copy_color_range_flag: The copy_color_range_flag of this ColorConfig.
        :type: bool
        """

        if copy_color_range_flag is not None:
            if not isinstance(copy_color_range_flag, bool):
                raise TypeError("Invalid type for `copy_color_range_flag`, type has to be `bool`")

        self._copy_color_range_flag = copy_color_range_flag

    @property
    def copy_color_transfer_flag(self):
        # type: () -> bool
        """Gets the copy_color_transfer_flag of this ColorConfig.

        Copy the color transfer setting from the input source

        :return: The copy_color_transfer_flag of this ColorConfig.
        :rtype: bool
        """
        return self._copy_color_transfer_flag

    @copy_color_transfer_flag.setter
    def copy_color_transfer_flag(self, copy_color_transfer_flag):
        # type: (bool) -> None
        """Sets the copy_color_transfer_flag of this ColorConfig.

        Copy the color transfer setting from the input source

        :param copy_color_transfer_flag: The copy_color_transfer_flag of this ColorConfig.
        :type: bool
        """

        if copy_color_transfer_flag is not None:
            if not isinstance(copy_color_transfer_flag, bool):
                raise TypeError("Invalid type for `copy_color_transfer_flag`, type has to be `bool`")

        self._copy_color_transfer_flag = copy_color_transfer_flag

    @property
    def chroma_location(self):
        # type: () -> ChromaLocation
        """Gets the chroma_location of this ColorConfig.

        The chroma location to be applied

        :return: The chroma_location of this ColorConfig.
        :rtype: ChromaLocation
        """
        return self._chroma_location

    @chroma_location.setter
    def chroma_location(self, chroma_location):
        # type: (ChromaLocation) -> None
        """Sets the chroma_location of this ColorConfig.

        The chroma location to be applied

        :param chroma_location: The chroma_location of this ColorConfig.
        :type: ChromaLocation
        """

        if chroma_location is not None:
            if not isinstance(chroma_location, ChromaLocation):
                raise TypeError("Invalid type for `chroma_location`, type has to be `ChromaLocation`")

        self._chroma_location = chroma_location

    @property
    def color_space(self):
        # type: () -> ColorSpace
        """Gets the color_space of this ColorConfig.

        The color space to be applied. If used on a Dolby Vision stream, this value must be set to UNSPECIFIED.

        :return: The color_space of this ColorConfig.
        :rtype: ColorSpace
        """
        return self._color_space

    @color_space.setter
    def color_space(self, color_space):
        # type: (ColorSpace) -> None
        """Sets the color_space of this ColorConfig.

        The color space to be applied. If used on a Dolby Vision stream, this value must be set to UNSPECIFIED.

        :param color_space: The color_space of this ColorConfig.
        :type: ColorSpace
        """

        if color_space is not None:
            if not isinstance(color_space, ColorSpace):
                raise TypeError("Invalid type for `color_space`, type has to be `ColorSpace`")

        self._color_space = color_space

    @property
    def color_primaries(self):
        # type: () -> ColorPrimaries
        """Gets the color_primaries of this ColorConfig.

        The color primaries to be applied. If used on a Dolby Vision stream, this value must be set to UNSPECIFIED.

        :return: The color_primaries of this ColorConfig.
        :rtype: ColorPrimaries
        """
        return self._color_primaries

    @color_primaries.setter
    def color_primaries(self, color_primaries):
        # type: (ColorPrimaries) -> None
        """Sets the color_primaries of this ColorConfig.

        The color primaries to be applied. If used on a Dolby Vision stream, this value must be set to UNSPECIFIED.

        :param color_primaries: The color_primaries of this ColorConfig.
        :type: ColorPrimaries
        """

        if color_primaries is not None:
            if not isinstance(color_primaries, ColorPrimaries):
                raise TypeError("Invalid type for `color_primaries`, type has to be `ColorPrimaries`")

        self._color_primaries = color_primaries

    @property
    def color_range(self):
        # type: () -> ColorRange
        """Gets the color_range of this ColorConfig.

        The color range to be applied. If used on a Dolby Vision stream, this value must be set to JPEG.

        :return: The color_range of this ColorConfig.
        :rtype: ColorRange
        """
        return self._color_range

    @color_range.setter
    def color_range(self, color_range):
        # type: (ColorRange) -> None
        """Sets the color_range of this ColorConfig.

        The color range to be applied. If used on a Dolby Vision stream, this value must be set to JPEG.

        :param color_range: The color_range of this ColorConfig.
        :type: ColorRange
        """

        if color_range is not None:
            if not isinstance(color_range, ColorRange):
                raise TypeError("Invalid type for `color_range`, type has to be `ColorRange`")

        self._color_range = color_range

    @property
    def color_transfer(self):
        # type: () -> ColorTransfer
        """Gets the color_transfer of this ColorConfig.

        The color transfer to be applied. If used on a Dolby Vision stream, this value must be set to UNSPECIFIED.

        :return: The color_transfer of this ColorConfig.
        :rtype: ColorTransfer
        """
        return self._color_transfer

    @color_transfer.setter
    def color_transfer(self, color_transfer):
        # type: (ColorTransfer) -> None
        """Sets the color_transfer of this ColorConfig.

        The color transfer to be applied. If used on a Dolby Vision stream, this value must be set to UNSPECIFIED.

        :param color_transfer: The color_transfer of this ColorConfig.
        :type: ColorTransfer
        """

        if color_transfer is not None:
            if not isinstance(color_transfer, ColorTransfer):
                raise TypeError("Invalid type for `color_transfer`, type has to be `ColorTransfer`")

        self._color_transfer = color_transfer

    @property
    def input_color_space(self):
        # type: () -> InputColorSpace
        """Gets the input_color_space of this ColorConfig.

        Override the color space detected in the input file. If not set the input color space will be automatically detected if possible.

        :return: The input_color_space of this ColorConfig.
        :rtype: InputColorSpace
        """
        return self._input_color_space

    @input_color_space.setter
    def input_color_space(self, input_color_space):
        # type: (InputColorSpace) -> None
        """Sets the input_color_space of this ColorConfig.

        Override the color space detected in the input file. If not set the input color space will be automatically detected if possible.

        :param input_color_space: The input_color_space of this ColorConfig.
        :type: InputColorSpace
        """

        if input_color_space is not None:
            if not isinstance(input_color_space, InputColorSpace):
                raise TypeError("Invalid type for `input_color_space`, type has to be `InputColorSpace`")

        self._input_color_space = input_color_space

    @property
    def input_color_range(self):
        # type: () -> InputColorRange
        """Gets the input_color_range of this ColorConfig.

        Override the color range detected in the input file. If not set the input color range will be automatically detected if possible.

        :return: The input_color_range of this ColorConfig.
        :rtype: InputColorRange
        """
        return self._input_color_range

    @input_color_range.setter
    def input_color_range(self, input_color_range):
        # type: (InputColorRange) -> None
        """Sets the input_color_range of this ColorConfig.

        Override the color range detected in the input file. If not set the input color range will be automatically detected if possible.

        :param input_color_range: The input_color_range of this ColorConfig.
        :type: InputColorRange
        """

        if input_color_range is not None:
            if not isinstance(input_color_range, InputColorRange):
                raise TypeError("Invalid type for `input_color_range`, type has to be `InputColorRange`")

        self._input_color_range = input_color_range

    @property
    def input_color_primaries(self):
        # type: () -> InputColorPrimaries
        """Gets the input_color_primaries of this ColorConfig.

        Override the color primaries detected in the input file. If not set the input color primaries will be automatically detected if possible.

        :return: The input_color_primaries of this ColorConfig.
        :rtype: InputColorPrimaries
        """
        return self._input_color_primaries

    @input_color_primaries.setter
    def input_color_primaries(self, input_color_primaries):
        # type: (InputColorPrimaries) -> None
        """Sets the input_color_primaries of this ColorConfig.

        Override the color primaries detected in the input file. If not set the input color primaries will be automatically detected if possible.

        :param input_color_primaries: The input_color_primaries of this ColorConfig.
        :type: InputColorPrimaries
        """

        if input_color_primaries is not None:
            if not isinstance(input_color_primaries, InputColorPrimaries):
                raise TypeError("Invalid type for `input_color_primaries`, type has to be `InputColorPrimaries`")

        self._input_color_primaries = input_color_primaries

    @property
    def input_color_transfer(self):
        # type: () -> InputColorTransfer
        """Gets the input_color_transfer of this ColorConfig.

        Override the color transfer detected in the input file. If not set the input color transfer will be automatically detected if possible.

        :return: The input_color_transfer of this ColorConfig.
        :rtype: InputColorTransfer
        """
        return self._input_color_transfer

    @input_color_transfer.setter
    def input_color_transfer(self, input_color_transfer):
        # type: (InputColorTransfer) -> None
        """Sets the input_color_transfer of this ColorConfig.

        Override the color transfer detected in the input file. If not set the input color transfer will be automatically detected if possible.

        :param input_color_transfer: The input_color_transfer of this ColorConfig.
        :type: InputColorTransfer
        """

        if input_color_transfer is not None:
            if not isinstance(input_color_transfer, InputColorTransfer):
                raise TypeError("Invalid type for `input_color_transfer`, type has to be `InputColorTransfer`")

        self._input_color_transfer = input_color_transfer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ColorConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.progressive_ts_api import ProgressiveTsApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.id3_api import Id3Api
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.progressive_ts_muxing_list_query_params import ProgressiveTsMuxingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class HlsVersion(Enum):
    HLS_V3 = "3"
    HLS_V4 = "4"
    HLS_V5 = "5"
    HLS_V6 = "6"
    HLS_V7 = "7"
    HLS_V8 = "8"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamConditionsMode(Enum):
    DROP_MUXING = "DROP_MUXING"
    DROP_STREAM = "DROP_STREAM"



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class PlayerVersion(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 version=None,
                 cdn_url=None,
                 download_url=None,
                 created_at=None):
        # type: (string_types, string_types, string_types, string_types, datetime) -> None
        super(PlayerVersion, self).__init__(id_=id_)

        self._version = None
        self._cdn_url = None
        self._download_url = None
        self._created_at = None
        self.discriminator = None

        if version is not None:
            self.version = version
        if cdn_url is not None:
            self.cdn_url = cdn_url
        if download_url is not None:
            self.download_url = download_url
        if created_at is not None:
            self.created_at = created_at

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(PlayerVersion, self), 'openapi_types'):
            types = getattr(super(PlayerVersion, self), 'openapi_types')

        types.update({
            'version': 'string_types',
            'cdn_url': 'string_types',
            'download_url': 'string_types',
            'created_at': 'datetime'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(PlayerVersion, self), 'attribute_map'):
            attributes = getattr(super(PlayerVersion, self), 'attribute_map')

        attributes.update({
            'version': 'version',
            'cdn_url': 'cdnUrl',
            'download_url': 'downloadUrl',
            'created_at': 'createdAt'
        })
        return attributes

    @property
    def version(self):
        # type: () -> string_types
        """Gets the version of this PlayerVersion.

        Version of the Player (required)

        :return: The version of this PlayerVersion.
        :rtype: string_types
        """
        return self._version

    @version.setter
    def version(self, version):
        # type: (string_types) -> None
        """Sets the version of this PlayerVersion.

        Version of the Player (required)

        :param version: The version of this PlayerVersion.
        :type: string_types
        """

        if version is not None:
            if not isinstance(version, string_types):
                raise TypeError("Invalid type for `version`, type has to be `string_types`")

        self._version = version

    @property
    def cdn_url(self):
        # type: () -> string_types
        """Gets the cdn_url of this PlayerVersion.

        URL of the specified player (required)

        :return: The cdn_url of this PlayerVersion.
        :rtype: string_types
        """
        return self._cdn_url

    @cdn_url.setter
    def cdn_url(self, cdn_url):
        # type: (string_types) -> None
        """Sets the cdn_url of this PlayerVersion.

        URL of the specified player (required)

        :param cdn_url: The cdn_url of this PlayerVersion.
        :type: string_types
        """

        if cdn_url is not None:
            if not isinstance(cdn_url, string_types):
                raise TypeError("Invalid type for `cdn_url`, type has to be `string_types`")

        self._cdn_url = cdn_url

    @property
    def download_url(self):
        # type: () -> string_types
        """Gets the download_url of this PlayerVersion.

        Download URL of the specified player package (required)

        :return: The download_url of this PlayerVersion.
        :rtype: string_types
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        # type: (string_types) -> None
        """Sets the download_url of this PlayerVersion.

        Download URL of the specified player package (required)

        :param download_url: The download_url of this PlayerVersion.
        :type: string_types
        """

        if download_url is not None:
            if not isinstance(download_url, string_types):
                raise TypeError("Invalid type for `download_url`, type has to be `string_types`")

        self._download_url = download_url

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this PlayerVersion.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ (required)

        :return: The created_at of this PlayerVersion.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this PlayerVersion.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ (required)

        :param created_at: The created_at of this PlayerVersion.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(PlayerVersion, self), "to_dict"):
            result = super(PlayerVersion, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayerVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.player.player_api import PlayerApi
from bitmovin_api_sdk.player.channels.channels_api import ChannelsApi
from bitmovin_api_sdk.player.licenses.licenses_api import LicensesApi
from bitmovin_api_sdk.player.custom_builds.custom_builds_api import CustomBuildsApi



from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.trimming_api import TrimmingApi
from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.time_based.time_based_api import TimeBasedApi
from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.timecode_track.timecode_track_api import TimecodeTrackApi
from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.h264_picture_timing.h264_picture_timing_api import H264PictureTimingApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class H262PresetConfiguration(Enum):
    XDCAM_HD_422 = "XDCAM_HD_422"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyDigitalPlusSurroundMixLevel(Enum):
    MINUS_1_5_DB = "MINUS_1_5_DB"
    MINUS_3_DB = "MINUS_3_DB"
    MINUS_4_5_DB = "MINUS_4_5_DB"
    MINUS_6_DB = "MINUS_6_DB"
    MINUS_INFINITY_DB = "MINUS_INFINITY_DB"



from bitmovin_api_sdk.encoding.configurations.audio.dts_passthrough.dts_passthrough_api import DtsPassthroughApi
from bitmovin_api_sdk.encoding.configurations.audio.dts_passthrough.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.dts_passthrough.dts_passthrough_audio_configuration_list_query_params import DtsPassthroughAudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class CustomPlayerBuildDownload(object):
    @poscheck_model
    def __init__(self,
                 download_link=None,
                 expires_at=None):
        # type: (string_types, datetime) -> None

        self._download_link = None
        self._expires_at = None
        self.discriminator = None

        if download_link is not None:
            self.download_link = download_link
        if expires_at is not None:
            self.expires_at = expires_at

    @property
    def openapi_types(self):
        types = {
            'download_link': 'string_types',
            'expires_at': 'datetime'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'download_link': 'downloadLink',
            'expires_at': 'expiresAt'
        }
        return attributes

    @property
    def download_link(self):
        # type: () -> string_types
        """Gets the download_link of this CustomPlayerBuildDownload.

        The link to download the custom built player (required)

        :return: The download_link of this CustomPlayerBuildDownload.
        :rtype: string_types
        """
        return self._download_link

    @download_link.setter
    def download_link(self, download_link):
        # type: (string_types) -> None
        """Sets the download_link of this CustomPlayerBuildDownload.

        The link to download the custom built player (required)

        :param download_link: The download_link of this CustomPlayerBuildDownload.
        :type: string_types
        """

        if download_link is not None:
            if not isinstance(download_link, string_types):
                raise TypeError("Invalid type for `download_link`, type has to be `string_types`")

        self._download_link = download_link

    @property
    def expires_at(self):
        # type: () -> datetime
        """Gets the expires_at of this CustomPlayerBuildDownload.

        Until this date the download link is valid and can be downloaded. (required)

        :return: The expires_at of this CustomPlayerBuildDownload.
        :rtype: datetime
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        # type: (datetime) -> None
        """Sets the expires_at of this CustomPlayerBuildDownload.

        Until this date the download link is valid and can be downloaded. (required)

        :param expires_at: The expires_at of this CustomPlayerBuildDownload.
        :type: datetime
        """

        if expires_at is not None:
            if not isinstance(expires_at, datetime):
                raise TypeError("Invalid type for `expires_at`, type has to be `datetime`")

        self._expires_at = expires_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomPlayerBuildDownload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.prewarmed_encoder_pool import PrewarmedEncoderPool
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.schedules.schedules_api import SchedulesApi
from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.prewarmed_encoder_pool_list_query_params import PrewarmedEncoderPoolListQueryParams


class PrewarmedEncoderPoolsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(PrewarmedEncoderPoolsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.schedules = SchedulesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, prewarmed_encoder_pool, **kwargs):
        # type: (PrewarmedEncoderPool, dict) -> PrewarmedEncoderPool
        """Create prewarmed encoder pool

        :param prewarmed_encoder_pool: The prewarmed encoder pool to be created
        :type prewarmed_encoder_pool: PrewarmedEncoderPool, required
        :return: Prewarmed encoder pool
        :rtype: PrewarmedEncoderPool
        """

        return self.api_client.post(
            '/encoding/infrastructure/prewarmed-encoder-pools',
            prewarmed_encoder_pool,
            type=PrewarmedEncoderPool,
            **kwargs
        )

    def delete(self, pool_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete prewarmed encoder pool

        :param pool_id: Id of the prewarmed encoder pool
        :type pool_id: string_types, required
        :return: Id of the prewarmed encoder pool that was deleted
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/infrastructure/prewarmed-encoder-pools/{pool_id}',
            path_params={'pool_id': pool_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, pool_id, **kwargs):
        # type: (string_types, dict) -> PrewarmedEncoderPool
        """Prewarmed encoder pool details

        :param pool_id: Id of the prewarmed encoder pool
        :type pool_id: string_types, required
        :return: Prewarmed encoder pool
        :rtype: PrewarmedEncoderPool
        """

        return self.api_client.get(
            '/encoding/infrastructure/prewarmed-encoder-pools/{pool_id}',
            path_params={'pool_id': pool_id},
            type=PrewarmedEncoderPool,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (PrewarmedEncoderPoolListQueryParams, dict) -> PrewarmedEncoderPool
        """List prewarmed encoder pools

        :param query_params: Query parameters
        :type query_params: PrewarmedEncoderPoolListQueryParams
        :return: List of prewarmed encoder pools
        :rtype: PrewarmedEncoderPool
        """

        return self.api_client.get(
            '/encoding/infrastructure/prewarmed-encoder-pools',
            query_params=query_params,
            pagination_response=True,
            type=PrewarmedEncoderPool,
            **kwargs
        )

    def start(self, pool_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Start prewarmed encoder pool

        :param pool_id: Id of the prewarmed encoder pool to be started
        :type pool_id: string_types, required
        :return: Id of the prewarmed encoder pool
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/infrastructure/prewarmed-encoder-pools/{pool_id}/start',
            path_params={'pool_id': pool_id},
            type=BitmovinResponse,
            **kwargs
        )

    def stop(self, pool_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Stop prewarmed encoder pool

        :param pool_id: Id of the prewarmed encoder pool to be stopped
        :type pool_id: string_types, required
        :return: Id of the prewarmed encoder pool
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/infrastructure/prewarmed-encoder-pools/{pool_id}/stop',
            path_params={'pool_id': pool_id},
            type=BitmovinResponse,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.playready.playready_api import PlayreadyApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.playready.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.playready.play_ready_drm_list_query_params import PlayReadyDrmListQueryParams



from bitmovin_api_sdk.encoding.filters.conform.conform_api import ConformApi
from bitmovin_api_sdk.encoding.filters.conform.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.conform.conform_filter_list_query_params import ConformFilterListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_impression_details import AnalyticsImpressionDetails
from bitmovin_api_sdk.models.analytics_impressions_query import AnalyticsImpressionsQuery
from bitmovin_api_sdk.models.analytics_impressions_response import AnalyticsImpressionsResponse
from bitmovin_api_sdk.models.analytics_license_key import AnalyticsLicenseKey
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.analytics.impressions.ads.ads_api import AdsApi
from bitmovin_api_sdk.analytics.impressions.errors.errors_api import ErrorsApi


class ImpressionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ImpressionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.ads = AdsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.errors = ErrorsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, impression_id, analytics_license_key, **kwargs):
        # type: (string_types, AnalyticsLicenseKey, dict) -> AnalyticsImpressionDetails
        """Impression Details

        :param impression_id: Impression id
        :type impression_id: string_types, required
        :param analytics_license_key: Analytics license
        :type analytics_license_key: AnalyticsLicenseKey, required
        :return: Service specific result
        :rtype: AnalyticsImpressionDetails
        """

        return self.api_client.post(
            '/analytics/impressions/{impression_id}',
            analytics_license_key,
            path_params={'impression_id': impression_id},
            type=AnalyticsImpressionDetails,
            **kwargs
        )

    def get_impressions(self, analytics_impressions_query, **kwargs):
        # type: (AnalyticsImpressionsQuery, dict) -> AnalyticsImpressionsResponse
        """List impressions

        :param analytics_impressions_query: Analytics impressions query object
        :type analytics_impressions_query: AnalyticsImpressionsQuery, required
        :return: List of Impressions
        :rtype: AnalyticsImpressionsResponse
        """

        return self.api_client.post(
            '/analytics/impressions',
            analytics_impressions_query,
            type=AnalyticsImpressionsResponse,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_max_concurrent_viewers_response import AnalyticsMaxConcurrentViewersResponse
from bitmovin_api_sdk.models.analytics_metrics_query_request import AnalyticsMetricsQueryRequest
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class MaxConcurrentviewersApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(MaxConcurrentviewersApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, analytics_metrics_query_request, **kwargs):
        # type: (AnalyticsMetricsQueryRequest, dict) -> AnalyticsMaxConcurrentViewersResponse
        """Get metrics data

        :param analytics_metrics_query_request: Analytics metrics query object
        :type analytics_metrics_query_request: AnalyticsMetricsQueryRequest, required
        :return: Service specific result
        :rtype: AnalyticsMaxConcurrentViewersResponse
        """

        return self.api_client.post(
            '/analytics/metrics/max-concurrentviewers',
            analytics_metrics_query_request,
            type=AnalyticsMaxConcurrentViewersResponse,
            **kwargs
        )



from bitmovin_api_sdk.encoding.manifests.hls.streams.custom_tags.custom_tags_api import CustomTagsApi
from bitmovin_api_sdk.encoding.manifests.hls.streams.custom_tags.custom_tag_list_query_params import CustomTagListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class ResponseErrorData(object):
    @poscheck_model
    def __init__(self,
                 code=None,
                 message=None,
                 developer_message=None,
                 links=None,
                 details=None):
        # type: (int, string_types, string_types, list[Link], list[Message]) -> None

        self._code = None
        self._message = None
        self._developer_message = None
        self._links = list()
        self._details = list()
        self.discriminator = None

        if code is not None:
            self.code = code
        if message is not None:
            self.message = message
        if developer_message is not None:
            self.developer_message = developer_message
        if links is not None:
            self.links = links
        if details is not None:
            self.details = details

    @property
    def openapi_types(self):
        types = {
            'code': 'int',
            'message': 'string_types',
            'developer_message': 'string_types',
            'links': 'list[Link]',
            'details': 'list[Message]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'code': 'code',
            'message': 'message',
            'developer_message': 'developerMessage',
            'links': 'links',
            'details': 'details'
        }
        return attributes

    @property
    def code(self):
        # type: () -> int
        """Gets the code of this ResponseErrorData.

        Contains an error code as defined in https://bitmovin.com/encoding-documentation/bitmovin-api/#/introduction/api-error-codes (required)

        :return: The code of this ResponseErrorData.
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        # type: (int) -> None
        """Sets the code of this ResponseErrorData.

        Contains an error code as defined in https://bitmovin.com/encoding-documentation/bitmovin-api/#/introduction/api-error-codes (required)

        :param code: The code of this ResponseErrorData.
        :type: int
        """

        if code is not None:
            if not isinstance(code, int):
                raise TypeError("Invalid type for `code`, type has to be `int`")

        self._code = code

    @property
    def message(self):
        # type: () -> string_types
        """Gets the message of this ResponseErrorData.

        General error message (required)

        :return: The message of this ResponseErrorData.
        :rtype: string_types
        """
        return self._message

    @message.setter
    def message(self, message):
        # type: (string_types) -> None
        """Sets the message of this ResponseErrorData.

        General error message (required)

        :param message: The message of this ResponseErrorData.
        :type: string_types
        """

        if message is not None:
            if not isinstance(message, string_types):
                raise TypeError("Invalid type for `message`, type has to be `string_types`")

        self._message = message

    @property
    def developer_message(self):
        # type: () -> string_types
        """Gets the developer_message of this ResponseErrorData.

        More detailed message meant for developers (required)

        :return: The developer_message of this ResponseErrorData.
        :rtype: string_types
        """
        return self._developer_message

    @developer_message.setter
    def developer_message(self, developer_message):
        # type: (string_types) -> None
        """Sets the developer_message of this ResponseErrorData.

        More detailed message meant for developers (required)

        :param developer_message: The developer_message of this ResponseErrorData.
        :type: string_types
        """

        if developer_message is not None:
            if not isinstance(developer_message, string_types):
                raise TypeError("Invalid type for `developer_message`, type has to be `string_types`")

        self._developer_message = developer_message

    @property
    def links(self):
        # type: () -> list[Link]
        """Gets the links of this ResponseErrorData.

        collection of links to webpages containing further information on the topic

        :return: The links of this ResponseErrorData.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        # type: (list) -> None
        """Sets the links of this ResponseErrorData.

        collection of links to webpages containing further information on the topic

        :param links: The links of this ResponseErrorData.
        :type: list[Link]
        """

        if links is not None:
            if not isinstance(links, list):
                raise TypeError("Invalid type for `links`, type has to be `list[Link]`")

        self._links = links

    @property
    def details(self):
        # type: () -> list[Message]
        """Gets the details of this ResponseErrorData.

        collection of messages containing more detailed information on the cause of the error

        :return: The details of this ResponseErrorData.
        :rtype: list[Message]
        """
        return self._details

    @details.setter
    def details(self, details):
        # type: (list) -> None
        """Sets the details of this ResponseErrorData.

        collection of messages containing more detailed information on the cause of the error

        :param details: The details of this ResponseErrorData.
        :type: list[Message]
        """

        if details is not None:
            if not isinstance(details, list):
                raise TypeError("Invalid type for `details`, type has to be `list[Message]`")

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseErrorData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
